@@ -97,7 +97,7 @@ int v_fsck_send_msg(int msg_num, const char *file_name, int line_number, ...) {
 	vsnprintf(msg_string, sizeof(msg_string), message->msg_txt, args);
 	va_end(args);
 
-	sprintf(debug_detail, " [%s:%d]\n", file_name, line_number);
+	sprintf(debug_detail, " [%s:%d]\n", basename(file_name), line_number);
 
 	if (message->msg_level <= msg_lvl) {
 		printf(msg_string);
