@@ -150,217 +150,6 @@ int backout_EA(struct dinode *ino_ptr, struct fsck_inode_record *ino_recptr)
 	return (bea_rc);
 }
 
-/*****************************************************************************
- * NAME: calculate_dasd_used
- *
- * FUNCTION: Calculate the cumulative amount of dasd used for each directory
- *           in the file system.
- *
- * PARAMETERS:  none
- *
- * RETURNS:
- *      success: FSCK_OK
- *      failure: something else
- */
-int calculate_dasd_used()
-{
-	int cdu_rc = FSCK_OK;
-	uint32_t ino_idx;
-	struct fsck_inode_record *this_inorec;
-	struct fsck_inode_record *this_child_inorec;
-	struct fsck_inode_record *this_parent_inorec;
-	struct fsck_inode_record *next_parent_inorec;
-	int aggregate_inode = 0;
-	int alloc_ifnull = 0;
-	int32_t this_level;
-
-	/*
-	 * In the first step we make a single pass on the inode records:
-	 *
-	 *     if the inode represents a file which is not an orphan then the
-	 *     number of blocks used by the file is added to the cummulative
-	 *     total for the parent inode.
-	 *
-	 *     if the inode represents a directory then we figure out the
-	 *     distance, in the fileset directory tree, between this inode and
-	 *     the root directory inode.
-	 */
-	cdu_rc = get_inorecptr_first(aggregate_inode, &ino_idx, &this_inorec);
-	if ((cdu_rc != FSCK_OK) || (this_inorec == NULL))
-		goto out;
-
-	while (ino_idx < FILESET_OBJECT_I) {
-		/*
-		 * not interesting until we get past the root inode
-		 * and the special fileset inodes.
-		 */
-		cdu_rc =
-		    get_inorecptr_next(aggregate_inode, &ino_idx, &this_inorec);
-		if ((cdu_rc != FSCK_OK) || (this_inorec == NULL))
-			goto out;
-	}
-
-	while (this_inorec != NULL) {
-
-		if ((!this_inorec->in_use) || this_inorec->selected_to_rls)
-			goto next_inode;
-
-		if (this_inorec->inode_type != directory_inode) {
-			/* it's a file */
-			if (this_inorec->parent_inonum == 0)	/* orphan */
-				goto next_inode;
-
-			cdu_rc = get_inorecptr(aggregate_inode, alloc_ifnull,
-					       this_inorec->parent_inonum,
-					       &this_parent_inorec);
-			if ((cdu_rc == FSCK_OK) && (this_parent_inorec == NULL))
-				cdu_rc = FSCK_INTERNAL_ERROR_63;
-
-			if (cdu_rc != FSCK_OK)
-				goto out;
-
-			this_parent_inorec->cumm_blocks +=
-			    this_inorec->cumm_blocks;
-
-			goto next_inode;
-		}
-		/* it's a directory */
-		if (this_inorec->dtree_level != -1)
-			/* distance already known */
-			goto next_inode;
-
-		if (this_inorec->parent_inonum == 0) {
-			/* it's an orphan */
-			this_inorec->dtree_level = 0;
-			if (this_inorec->dtree_level > agg_recptr->tree_height)
-				agg_recptr->tree_height =
-				    this_inorec->dtree_level;
-			goto next_inode;
-		}
-		/* it's not an orphan */
-		cdu_rc = get_inorecptr(aggregate_inode, alloc_ifnull,
-				       this_inorec->parent_inonum,
-				       &this_parent_inorec);
-		if ((cdu_rc == FSCK_OK) && (this_parent_inorec == NULL))
-			cdu_rc = FSCK_INTERNAL_ERROR_64;
-
-		if (cdu_rc != FSCK_OK)
-			goto out;
-
-		agg_recptr->treeStack = NULL;
-		cdu_rc = treeStack_push(this_inorec);
-		while (this_parent_inorec->dtree_level == -1) {
-			if (this_parent_inorec->parent_inonum == 0) {
-				/* orphan */
-				this_parent_inorec->dtree_level = 0;
-			} else {
-				/* not an orphan */
-				cdu_rc =
-				    get_inorecptr(aggregate_inode, alloc_ifnull,
-						  this_parent_inorec->
-						  parent_inonum,
-						  &next_parent_inorec);
-				if ((cdu_rc == FSCK_OK)
-				    && (next_parent_inorec == NULL))
-					cdu_rc = FSCK_INTERNAL_ERROR_65;
-
-				if (cdu_rc == FSCK_OK) {
-					/* located next parent's inode rec */
-					cdu_rc =
-					    treeStack_push(this_parent_inorec);
-					this_parent_inorec = next_parent_inorec;
-				}
-
-				if (cdu_rc != FSCK_OK)
-					goto out;
-			}
-		}
-
-		this_level = this_parent_inorec->dtree_level;
-		/*
-		 * this is the first known level number
-		 * (distance) in the chain of directories
-		 * from here to the root.
-		 */
-		while (agg_recptr->treeStack != NULL) {
-			this_level++;
-			cdu_rc = treeStack_pop(&this_child_inorec);
-			this_child_inorec->dtree_level = this_level;
-			if (this_child_inorec->dtree_level >
-			    agg_recptr->tree_height) {
-				agg_recptr->tree_height =
-				    this_child_inorec->dtree_level;
-			}
-		}
-	      next_inode:
-		cdu_rc =
-		    get_inorecptr_next(aggregate_inode, &ino_idx, &this_inorec);
-		if (cdu_rc != FSCK_OK)
-			goto out;
-	}
-
-	/*
-	 *
-	 * In the second step we make one pass on the inode records for each
-	 * level in the fileset directory tree, since we must accumulate the
-	 * dasd used values from the bottom up.
-	 *
-	 */
-	this_level = agg_recptr->tree_height;
-	while (this_level > 0) {
-		cdu_rc = get_inorecptr_first(aggregate_inode, &ino_idx,
-					     &this_inorec);
-		if (cdu_rc != FSCK_OK)
-			goto out;
-
-		while ((this_inorec != NULL) && (ino_idx < FILESET_OBJECT_I)) {
-			/*
-			 * not interesting until we get past the root inode
-			 * and the special fileset inodes.
-			 */
-			cdu_rc = get_inorecptr_next(aggregate_inode, &ino_idx,
-						    &this_inorec);
-			if (cdu_rc != FSCK_OK)
-				goto out;
-		}
-
-		while (this_inorec != NULL) {
-
-			if ((this_inorec->in_use)
-			    && (!this_inorec->selected_to_rls)
-			    && (this_inorec->inode_type == directory_inode)
-			    && (this_inorec->dtree_level == this_level)) {
-				/*
-				 * inode in use and not selected to release and
-				 * type directory and dtree level is a match
-				 */
-				cdu_rc =
-				    get_inorecptr(aggregate_inode, alloc_ifnull,
-						  this_inorec->parent_inonum,
-						  &this_parent_inorec);
-				if ((cdu_rc == FSCK_OK)
-				    && (this_parent_inorec == NULL))
-					cdu_rc = FSCK_INTERNAL_ERROR_66;
-				if (cdu_rc != FSCK_OK)
-					goto out;
-
-				this_parent_inorec->cumm_blocks +=
-				    this_inorec->cumm_blocks;
-			}
-			cdu_rc =
-			    get_inorecptr_next(aggregate_inode, &ino_idx,
-					       &this_inorec);
-			if (cdu_rc != FSCK_OK)
-				goto out;
-
-		}
-		this_level--;
-	}
-
-      out:
-	return (cdu_rc);
-}
-
 /*****************************************************************************
  * NAME: clear_ACL_field
  *
@@ -1470,75 +1259,6 @@ int validate_ACL(struct dinode *inoptr, uint32_t inoidx,
 	return (vacl_rc);
 }
 
-/*****************************************************************************
- * NAME: validate_dasd_used
- *
- * FUNCTION: Verify that, for each directory with a dasd limit set, the
- *	     cumulative amount of dasd used matches the value stored in the
- *	     inode.
- *
- * PARAMETERS:  none
- *
- * RETURNS:
- *      success: FSCK_OK
- *      failure: something else
- */
-int validate_dasd_used()
-{
-	int vdu_rc = FSCK_OK;
-	uint32_t ino_idx;
-	struct dinode *inoptr;
-	struct fsck_inode_record *this_inorec;
-	int aggregate_inode = 0;	/* going for fileset inodes only */
-	int which_it = 0;	/* in release 1 there is only fileset 0 */
-	int64_t dasd_used = 0;
-
-	/*
-	 * We make a single pass on the inode records:
-	 *
-	 *     if the inode record shows that the inode has a dasd limit,
-	 *     verify that the dasd used amount stored in the inode matches
-	 *     the amount calculated for the inode by fsck.
-	 */
-	vdu_rc = get_inorecptr_first(aggregate_inode, &ino_idx, &this_inorec);
-
-	while ((vdu_rc == FSCK_OK) && (this_inorec != NULL)
-	       && (ino_idx < ROOT_I)) {
-		/* not interesting until we get to the root inode */
-		vdu_rc =
-		    get_inorecptr_next(aggregate_inode, &ino_idx, &this_inorec);
-	}			/* end while */
-
-	while ((vdu_rc == FSCK_OK) && (this_inorec != NULL)) {
-
-		if ((this_inorec->in_use) && (!this_inorec->selected_to_rls)) {
-			/* inode in use and not selected to release */
-			if (this_inorec->inode_type == directory_inode) {
-				/* it's a directory */
-				vdu_rc =
-				    inode_get(aggregate_inode, which_it,
-					      ino_idx, &inoptr);
-				if (vdu_rc != FSCK_OK)
-					goto out;
-
-				/* got the inode */
-				dasd_used = DASDUSED(&(inoptr->di_DASD));
-				if (dasd_used != this_inorec->cumm_blocks) {
-					/* it isn't right! */
-					this_inorec->crrct_cumm_blks = 1;
-					agg_recptr->corrections_needed = 1;
-					agg_recptr->corrections_approved = 1;
-				}
-			}
-		}
-		vdu_rc =
-		    get_inorecptr_next(aggregate_inode, &ino_idx, &this_inorec);
-	}
-
-      out:
-	return (vdu_rc);
-}
-
 /*****************************************************************************
  * NAME: validate_data
  *
@@ -2196,7 +1916,6 @@ int validate_record_fileset_inode(uint32_t inonum, uint32_t inoidx,
 	}
 
 	inorecptr->link_count -= inoptr->di_nlink;
-	inorecptr->dtree_level = -1;
 
 	/*
 	 * validate the inode's structures
@@ -2424,7 +2143,6 @@ int validate_record_fileset_inode(uint32_t inonum, uint32_t inoidx,
 	}
 	if ((vrfi_rc == FSCK_OK) && (!inorecptr->selected_to_rls)) {
 		/* looks like a keeper */
-		inorecptr->cumm_blocks = agg_recptr->this_inode.all_blks;
 		agg_recptr->blocks_for_eas += agg_recptr->this_inode.ea_blks;
 		agg_recptr->blocks_for_acls += agg_recptr->this_inode.acl_blks;
 		if (inorecptr->inode_type == directory_inode) {
