@@ -98,7 +98,7 @@ char Str_Name[JFS_NAME_MAX];
  *
  *     values are assigned when (if) the device is opened.
  */
-int Dev_IOPort;
+FILE *Dev_IOPort;
 uint32_t Dev_blksize;
 int32_t Dev_SectorSize;
 char log_device[512] = { 0 };
@@ -815,15 +815,12 @@ int create_lost_and_found()
 	new_inorecptr->inode_type = directory_inode;
 	new_inorecptr->link_count = 0;
 	new_inorecptr->parent_inonum = 0;
-	new_inorecptr->cumm_blocks = 0;
-	new_inorecptr->dtree_level = -1;
 	new_inorecptr->selected_to_rls = 0;
 	new_inorecptr->crrct_link_count = 0;
 	new_inorecptr->crrct_prnt_inonum = 0;
 	new_inorecptr->adj_entries = 0;
 	new_inorecptr->clr_ea_fld = 0;
 	new_inorecptr->clr_acl_fld = 0;
-	new_inorecptr->crrct_cumm_blks = 0;
 	new_inorecptr->inlineea_on = 0;
 	new_inorecptr->inlineea_off = 0;
 	new_inorecptr->inline_data_err = 0;
@@ -994,22 +991,6 @@ int final_processing()
 	}
 
 	if (agg_recptr->processing_readwrite) {
-		/*
-		 * if we have primed the dasd used fields,
-		 * turn off the flag so mount won't do it too.
-		 *
-		 * Also turn on the dasd enabled flag because if
-		 * this there has been no mount since enablement,
-		 * it isn't on yet.
-		 */
-		if (agg_recptr->prime_dasd_limits) {
-			sb_ptr->s_flag &= (~JFS_DASD_PRIME);
-			sb_ptr->s_flag |= JFS_DASD_ENABLED;
-			fsck_send_msg(fsck_DASDUSEDPRIMED);
-			if (!agg_recptr->active_dasd_limits) {
-				fsck_send_msg(fsck_DASDLIMITSPRIMED);
-			}
-		}
 		/*
 		 * Make sure the s_logdev is up to date in the superblock.
 		 */
@@ -1146,7 +1127,6 @@ int report_problems_setup_repairs()
 		    (this_inorec->inlineea_on) ||
 		    (this_inorec->inlineea_off) ||
 		    (this_inorec->inline_data_err) ||
-		    (this_inorec->crrct_cumm_blks) ||
 		    (this_inorec->cant_chkea) ||
 		    (this_inorec->adj_entries) || 
 		    (this_inorec->rebuild_dirtable) || 
@@ -1318,19 +1298,6 @@ int report_problems_setup_repairs()
 				fsck_send_msg(fsck_INOACL);
 			}
 		}
-		if ((rc == FSCK_OK) && (this_inorec->crrct_cumm_blks)) {
-			/* fix DASDused */
-			if (agg_recptr->processing_readwrite) {
-				/* we can fix this */
-				agg_recptr->corrections_approved = 1;
-				fsck_send_msg(fsck_WILLFIXINOMINOR);
-			} else {
-				/* we don't have write access */
-				this_inorec->inlineea_off = 0;
-				agg_recptr->ag_dirty = 1;
-				fsck_send_msg(fsck_INOMINOR);
-			}
-		}
 		if ((rc == FSCK_OK) && (this_inorec->inlineea_off)) {
 			/* turn off sect 4 avail flag */
 			if (agg_recptr->processing_readwrite) {
@@ -1671,20 +1638,6 @@ int initial_processing(int argc, char **argv)
 	    agg_recptr->ondev_fscklog_fsblk_length +
 	    agg_recptr->ondev_jlog_fsblk_length;
 	agg_recptr->superblk_ok = 1;
-	/*
-	 * note whether dasd limits are enabled for the volume
-	 */
-	if (agg_recptr->processing_readwrite) {
-		/* have write access */
-		if ((sb_ptr->s_flag & JFS_DASD_ENABLED) == JFS_DASD_ENABLED) {
-			agg_recptr->active_dasd_limits = 1;
-		}
-		if ((sb_ptr->s_flag & JFS_DASD_PRIME) == JFS_DASD_PRIME) {
-			agg_recptr->prime_dasd_limits = 1;
-			agg_recptr->corrections_needed = 1;
-			agg_recptr->corrections_approved = 1;
-		}
-	}
 	if ((!agg_recptr->parm_options[UFS_CHKDSK_LEVEL0]) && 
 	    (agg_recptr->processing_readonly)) {
 		/* user did not specify check only but we can only
@@ -2273,23 +2226,6 @@ int phase5_processing()
 	if (agg_recptr->processing_readwrite) {
 		/* have read/write access */
 		p5_rc = check_connectedness();
-		/*
-		 * now that all the parent child relationships have stabilized,
-		 * if there are any active dasd limits in the file system, we
-		 * can calculate the dasd used and verify the dinode field.
-		 *
-		 * If we're not going to just reset all dasd used fields, then
-		 * check to see which ones are now incorrect.
-		 */
-		if ((p5_rc == FSCK_OK) && ((agg_recptr->active_dasd_limits)
-					   || (agg_recptr->prime_dasd_limits))
-		    ) {
-			p5_rc = calculate_dasd_used();
-			if ((p5_rc == FSCK_OK)
-			    && (!agg_recptr->prime_dasd_limits)) {
-				p5_rc = validate_dasd_used();
-			}
-		}
 
 		if (p5_rc != FSCK_OK) {
 			agg_recptr->fsck_is_done = 1;
@@ -2530,14 +2466,14 @@ int phase9_processing()
 		    jfs_logform(Dev_IOPort, sb_ptr->s_bsize, sb_ptr->s_l2bsize,
 				sb_ptr->s_flag, addressPXD(&(sb_ptr->s_logpxd)),
 				lengthPXD(&(sb_ptr->s_logpxd)), NULL, NULL);
-	} else if (Log.fd && !uuid_is_null(sb_ptr->s_loguuid)) {
+	} else if (Log.fp && !uuid_is_null(sb_ptr->s_loguuid)) {
 		/* External log */
 		logformat_called = -1;
 #ifdef _JFS_DEBUG
 		printf("JFS fsck calling logformat \n");
 #endif
 		agg_recptr->logformat_rc =
-		    jfs_logform(Log.fd, Log.bsize, Log.l2bsize,
+		    jfs_logform(Log.fp, Log.bsize, Log.l2bsize,
 				sb_ptr->s_flag, 0, 0, sb_ptr->s_loguuid, NULL);
 	} else
 		/* Extern log was never opened or null s_loguuid */
@@ -2589,7 +2525,6 @@ int repair_fs_inodes()
 	struct dinode *ino_ptr;
 	struct fsck_ino_msg_info ino_msg_info;
 	struct fsck_ino_msg_info *msg_info_ptr;
-	int64_t dasd_used, dasd_limit;
 
 	msg_info_ptr = &ino_msg_info;
 	/* all fileset owned */
@@ -2604,13 +2539,12 @@ int repair_fs_inodes()
 			|| (this_inorec->adj_entries)
 			|| (this_inorec->clr_ea_fld)
 			|| (this_inorec->clr_acl_fld)
-			|| (this_inorec->crrct_cumm_blks)
 			|| (this_inorec->inlineea_on)
 			|| (this_inorec->inlineea_off)
 			|| (this_inorec->rebuild_dirtable)
 			|| (this_inorec->reconnect)
 			|| (this_inorec->link_count != 0))))
-			goto rfsi_prime_dasd;
+			goto rfsi_get_next;
 				
 		/* flagged for repair */
 		rfsi_rc = inode_get(aggregate_inode, which_it, 
@@ -2664,40 +2598,6 @@ int repair_fs_inodes()
 				      fsck_ref_msg(msg_info_ptr->msg_inopfx),
 				      msg_info_ptr->msg_inonum);
 		}
-		if (this_inorec->crrct_cumm_blks) {
-			/*                                  
-			 * correct DASD blocks used
-			 */
-			setDASDUSED(&(ino_ptr->di_DASD),
-				    this_inorec->cumm_blocks);
-			fsck_send_msg(fsck_INCDASDUSEDCRCT,
-				      fsck_ref_msg(msg_info_ptr->msg_inopfx),
-				      msg_info_ptr->msg_inonum);
-			fsck_send_msg(fsck_INOMINORFXD,
-				      fsck_ref_msg(msg_info_ptr->msg_inopfx),
-				      msg_info_ptr->msg_inonum);
-		} else if (this_inorec->inode_type == directory_inode) {
-			/*
-			 * it's a directory not flagged for dasd used
-			 * correction.
-			 */
-			/*
-			 * if we're priming the dasd used fields, do so.
-			 * if dasd limits have just now been enabled on the
-			 * volume, zero the limit field as well.
-			 */
-			if (agg_recptr->prime_dasd_limits) {
-				/*
-				 * we're priming dasd used fields
-				 */
-				setDASDUSED(&(ino_ptr->di_DASD),
-					    this_inorec->cumm_blocks);
-				if (!agg_recptr->active_dasd_limits) {
-					setDASDLIMIT(&ino_ptr->di_DASD,
-						     0);
-				}
-			}
-		}
 		if (this_inorec->reconnect) {
 			/*
 			 * reconnect
@@ -2807,44 +2707,6 @@ int repair_fs_inodes()
 			/* write it back to the device */
 			rfsi_rc = inode_put(ino_ptr);
 		}
-		goto rfsi_get_next;
-		
-      rfsi_prime_dasd:    		     
-		/*
-		 * if the inode isn't flagged for repair, check to see if we
-		 * are priming dasd used fields, and if so, whether this is an
-		 * in-use directory inode.
-		 */
-		if (agg_recptr->prime_dasd_limits && this_inorec->in_use && 
-		    (this_inorec->inode_type == directory_inode)) {
-			/*
-			 * read in the inode, set dasd used, and write it back out
-			 */
-			rfsi_rc = inode_get(aggregate_inode, which_it, ino_idx,
-					    &ino_ptr);
-
-			if (rfsi_rc == FSCK_OK) {
-				write_inode = 0;
-				dasd_used = DASDUSED(&(ino_ptr->di_DASD));
-				if (dasd_used != this_inorec->cumm_blocks) {
-					setDASDUSED(&(ino_ptr->di_DASD),
-						    this_inorec->cumm_blocks);
-					write_inode = -1;
-				}
-				if (!agg_recptr->active_dasd_limits) {
-					dasd_limit = 
-					    DASDLIMIT(&(ino_ptr->di_DASD));
-					if (dasd_limit != 0) {
-						setDASDLIMIT(&ino_ptr->di_DASD,
-							     0);
-						write_inode = -1;
-					}
-				}
-				if (write_inode) {
-					rfsi_rc = inode_put(ino_ptr);
-				}
-			}
-		}
 		
       rfsi_get_next:    	    
 		if (rfsi_rc == FSCK_OK) {
