@@ -77,7 +77,7 @@ extern char *Vol_Label;
   *
   *     values are assigned when (if) the device is opened.
   */
-int Dev_IOPort;
+FILE *Dev_IOPort;
 unsigned Dev_blksize;
 int Dev_SectorSize;
 
@@ -94,7 +94,7 @@ int xchklog_fscklog_fill_buffer(void);
 
 int xchklog_initial_processing(struct fscklog_record *);
 
-int open_device_read(char *);
+int open_device_read(const char *);
 
 int open_outfile(void);
 
@@ -258,7 +258,7 @@ int xchklog_final_processing()
 	 * Close the device
 	 */
 	if (local_recptr->device_is_open) {
-		pf_rc = close(Dev_IOPort);
+		pf_rc = fclose(Dev_IOPort);
 	}
 
 	/*
@@ -484,10 +484,10 @@ int xchklog_initial_processing(struct fscklog_record *local_recptr)
  *      success: 0
  *      failure: something else
  */
-int open_device_read(char *Device)
+int open_device_read(const char *Device)
 {
-	Dev_IOPort = open(Device, O_RDONLY, 0);
-	if (Dev_IOPort < 0) {
+	Dev_IOPort = fopen(Device, "r");
+	if (Dev_IOPort == NULL) {
 		send_msg(fsck_DEVOPENRDRC, ERROR_FILE_NOT_FOUND);
 		return ERROR_FILE_NOT_FOUND;
 	}
