@@ -15,6 +15,7 @@
  *   along with this program;  if not, write to the Free Software 
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
+#include "config.h"
 #include <errno.h>
 #include <fcntl.h>
 #include <unistd.h>
@@ -31,6 +32,11 @@
 #include "debug.h"
 
 #include <sys/ioctl.h>
+#if defined(__DragonFly__)
+#include <machine/param.h>
+#include <sys/diskslice.h>
+#include <sys/disklabel.h>
+#endif
 
 #if defined(__linux__) && defined(_IO) && !defined(BLKGETSIZE64)
 #define BLKGETSIZE64 _IOR(0x12, 114, size_t)
@@ -39,6 +45,45 @@
 #define BLKGETSIZE _IO(0x12,96)	/* return device size (sectors) */
 #endif
 
+/*
+ * NAME: ujfs_device_is_valid
+ *
+ * FUNCTION: Check device validity by examining stat modes.
+ *
+ * PRE CONDITIONS: 'device' must refer to an open device handle.
+ *
+ * PARAMETERS:
+ *      device_handle  - open device handle to check
+ *      st             - stat information if device handle not provided
+ *
+ * RETURNS: 0 if successful; anything else indicates failures
+ */
+int ujfs_device_is_valid(FILE *device_handle, struct stat *st)
+{
+	struct stat stat_data;
+	int rc = 0;
+
+	if (device_handle != NULL) {
+		rc = fstat(fileno(device_handle), &stat_data);
+		if (rc)
+			return -1;
+		st = &stat_data;
+	}
+	else if (st == NULL) {
+		return -1;
+	}
+
+	/* Do we have a block special device or regular file? */
+#if defined(__DragonFly__)
+	if (!S_ISCHR(st->st_mode) && !S_ISREG(st->st_mode))
+#else /* __linux__ etc. */
+	if (!S_ISBLK(st->st_mode) && !S_ISREG(st->st_mode))
+#endif
+		return -1;
+
+	return (rc);
+}
+ 
 /*
  * NAME: ujfs_get_dev_size
  *
@@ -59,7 +104,7 @@
  *
  * RETURNS: 0 if successful; anything else indicates failures
  */
-int ujfs_get_dev_size(int device, int64_t *size)
+int ujfs_get_dev_size(FILE *device, int64_t *size)
 {
 
 	off_t Starting_Position;	/* position within file/device upon
@@ -72,12 +117,11 @@ int ujfs_get_dev_size(int device, int64_t *size)
 					 * to read from/seek to. */
 	off_t Seek_Result;	/* value returned by lseek. */
 	size_t Read_Result = 0;	/* value returned by read. */
-	char Test_Byte;		/* used to validate a position that we
-				 * successfully lseek'ed to. */
 	int rc;
 	struct stat stat_data;
+	int devfd = fileno(device);
 
-	rc = fstat(device, &stat_data);
+	rc = fstat(devfd, &stat_data);
 	if (!rc && S_ISREG(stat_data.st_mode)) {
 		/* This is a regular file.  */
 		*size = (int64_t) ((stat_data.st_size / 1024) * 1024);
@@ -86,7 +130,7 @@ int ujfs_get_dev_size(int device, int64_t *size)
 #ifdef BLKGETSIZE64
 	{
 		uint64_t sz;
-		if (ioctl(device, BLKGETSIZE64, &sz) >= 0) {
+		if (ioctl(devfd, BLKGETSIZE64, &sz) >= 0) {
 			*size = sz;
 			return 0;
 		}
@@ -96,7 +140,7 @@ int ujfs_get_dev_size(int device, int64_t *size)
 	{
 		unsigned long num_sectors = 0;
 
-		if (ioctl(device, BLKGETSIZE, &num_sectors) >= 0) {
+		if (ioctl(devfd, BLKGETSIZE, &num_sectors) >= 0) {
 			/* for now, keep size as multiple of 1024, *
 			 * not 512, so eliminate any odd sector.   */
 			*size = PBSIZE * (int64_t) ((num_sectors / 2) * 2);
@@ -104,6 +148,50 @@ int ujfs_get_dev_size(int device, int64_t *size)
 		}
 	}
 #endif
+#if defined(__DragonFly__)
+	{
+		struct diskslices dss;
+		struct disklabel dl;
+		struct diskslice *sliceinfo;
+		int slice;
+		dev_t dev = stat_data.st_rdev;
+
+		rc = ioctl(devfd, DIOCGSLICEINFO, &dss);
+		if (rc < 0)
+			return -1;
+
+		slice = dkslice(dev);
+		sliceinfo = &dss.dss_slices[slice];
+
+		DBG_TRACE(("ujfs_get_device_size: slice = %d\n", slice));
+		
+		if (sliceinfo) {
+			if (slice == WHOLE_DISK_SLICE || slice == 0) {
+				*size = (int64_t) sliceinfo->ds_size * dss.dss_secsize;
+				DBG_TRACE(("ujfs_get_device_size: slice represents disk\n"));
+			} else {
+				if (sliceinfo->ds_label) {
+					DBG_TRACE(("ujfs_get_device_size: slice has disklabel\n"));
+					rc = ioctl(devfd, DIOCGDINFO, &dl);
+					if (!rc) {
+						*size = (int64_t) dl.d_secperunit * dss.dss_secsize;
+					} else {
+						return (-1);
+					}
+				}
+			}
+		} else {
+			return (-1);
+		}
+
+		DBG_TRACE(("ujfs_get_device_size: size in bytes = %ld\n", *size));
+		DBG_TRACE(("ujfs_get_device_size: size in megabytes = %ld\n",
+			*size / (1024 * 1024)));
+		
+		return 0;
+	}
+#endif
+
 	/*
 	 * If the ioctl above fails or is undefined, use a binary search to
 	 * find the last byte in the partition.  This works because an lseek to
@@ -115,7 +203,7 @@ int ujfs_get_dev_size(int device, int64_t *size)
 
 	/* Save the starting position so that we can restore it when we are
 	 * done! */
-	Starting_Position = lseek(device, 0, SEEK_CUR);
+	Starting_Position = fseeko(device, 0, SEEK_CUR);
 	if (Starting_Position < 0)
 		return ERROR_SEEK;
 
@@ -127,11 +215,11 @@ int ujfs_get_dev_size(int device, int64_t *size)
 	 */
 	do {
 		/* Seek to the location we wish to test. */
-		Seek_Result = lseek(device, Current_Position, SEEK_SET);
+		Seek_Result = fseeko(device, Current_Position, SEEK_SET);
 		if (Seek_Result == Current_Position) {
 			/* Can we read from this location? */
-			Read_Result = read(device, &Test_Byte, 1);
-			if (Read_Result == 1) {
+			Read_Result = fgetc(device);
+			if (Read_Result != EOF) {
 				/* The current test position is valid.  Save it
 				 * for future reference. */
 				Last_Valid_Position = Current_Position;
@@ -160,11 +248,11 @@ int ujfs_get_dev_size(int device, int64_t *size)
 		 * so we need to issue a different error message
 		 */
 		*size = 0;	/* Indicates not readable at all */
-		Seek_Result = lseek(device, Last_Valid_Position, SEEK_SET);
+		Seek_Result = fseeko(device, Last_Valid_Position, SEEK_SET);
 		if (Seek_Result == Last_Valid_Position) {
 			/* Can we read from this location? */
-			Read_Result = read(device, &Test_Byte, 1);
-			if (Read_Result == 1)
+			Read_Result = fgetc(device);
+			if (Read_Result != EOF)
 				/* non-zero indicates readable, but too small */
 				*size = 1;
 		}
@@ -190,11 +278,11 @@ int ujfs_get_dev_size(int device, int64_t *size)
 	 */
 	while ((First_Invalid_Position - Last_Valid_Position) > 2) {
 		/* Seek to the location we wish to test. */
-		Seek_Result = lseek(device, Current_Position, SEEK_SET);
+		Seek_Result = fseeko(device, Current_Position, SEEK_SET);
 		if (Seek_Result == Current_Position) {
 			/* Can we read from this location? */
-			Read_Result = read(device, &Test_Byte, 1);
-			if (Read_Result == 1) {
+			Read_Result = fgetc(device);
+			if (Read_Result != EOF) {
 				/* The current test position is valid.
 				 * Save it for future reference. */
 				Last_Valid_Position = Current_Position;
@@ -236,7 +324,7 @@ int ujfs_get_dev_size(int device, int64_t *size)
 
 restore:
 	/* Restore the original position. */
-	if (Starting_Position != lseek(device, Starting_Position, SEEK_SET))
+	if (Starting_Position != fseeko(device, Starting_Position, SEEK_SET))
 		return ERROR_SEEK;
 
 	return NO_ERROR;
@@ -270,7 +358,7 @@ restore:
  *
  * RETURNS:
  */
-int ujfs_rw_diskblocks(int dev_ptr,
+int ujfs_rw_diskblocks(FILE *dev_ptr,
 		       int64_t disk_offset, 
 		       int32_t disk_count, 
 		       void *data_buffer, 
@@ -278,22 +366,26 @@ int ujfs_rw_diskblocks(int dev_ptr,
 {
 	off_t Actual_Location;
 	size_t Bytes_Transferred;
+	int error = NO_ERROR;
 
-	Actual_Location = lseek(dev_ptr, disk_offset, SEEK_SET);
-	if ((Actual_Location < 0) || (Actual_Location != disk_offset))
-		return ERROR_SEEK;
+	Actual_Location = fseeko(dev_ptr, disk_offset, SEEK_SET);
+	if (Actual_Location < 0) {
+		error = ERROR_SEEK;
+		goto finished;
+	}
 
 	switch (mode) {
 	case GET:
-		Bytes_Transferred = read(dev_ptr, data_buffer, disk_count);
+		Bytes_Transferred = fread(data_buffer, 1, disk_count, dev_ptr);
 		break;
 	case PUT:
-		Bytes_Transferred = write(dev_ptr, data_buffer, disk_count);
+		Bytes_Transferred = fwrite(data_buffer, 1, disk_count, dev_ptr);
 		break;
 	default:
 		DBG_ERROR(("Internal error: %s(%d): bad mode: %d\n", __FILE__,
 			   __LINE__, mode))
-		    return ERROR_INVALID_HANDLE;
+			error = ERROR_INVALID_HANDLE;
+		    goto finished;
 		break;		/* Keep the compiler happy. */
 	}
 
@@ -307,18 +399,27 @@ int ujfs_rw_diskblocks(int dev_ptr,
 				Bytes_Transferred, disk_count, disk_offset);
 
 		if (mode == GET)
-			return ERROR_READ_FAULT;
+			error = ERROR_READ_FAULT;
 		else
-			return ERROR_WRITE_FAULT;
+			error = ERROR_WRITE_FAULT;
+		goto finished;
 	}
 
-	return NO_ERROR;
+finished:
+	if (error)
+		rewind(dev_ptr);
+	return (error);
 }
 
-int ujfs_flush_dev(int fd)
+int ujfs_flush_dev(FILE *fp)
 {
-	if (fsync(fd) == -1)
+	if (fsync(fileno(fp)) == -1)
 		return errno;
-
-	return ioctl(fd, BLKFLSBUF, 0);
+#if defined(__DragonFly__)
+	/* No explicit flushing required but we will call sync(2) */
+	sync();
+	return (0);
+#else
+	return ioctl(fileno(fp), BLKFLSBUF, 0);
+#endif
 }
