@@ -291,13 +291,12 @@ struct fsck_inode_record {
 	unsigned badblk_inode:1;
 	unsigned involved_in_dups:1;
 
-	unsigned crrct_cumm_blks:1;
 	unsigned rebuild_dirtable:1;
 	unsigned inlineea_on:1;
 	unsigned inlineea_off:1;
 
 	unsigned check_dir_index:1;
-	unsigned avail_flagbits:3;
+	unsigned avail_flagbits:4;
 	/*        end of flag bits           */
 	int8_t inode_type;	/* 1 : see constants above          */
 
@@ -311,13 +310,6 @@ struct fsck_inode_record {
 				 * Otherwise, this is the inode number
 				 * of the first observed parent.
 				 */
-	int64_t cumm_blocks;	/* 8 : number of blocks allocated to the
-				 * inode and, if this is a directory, to each
-				 * inode described in an entry
-				 */
-	int32_t dtree_level;	/* 4 : distance, in the fileset directory tree,
-				 * from the root (inode 2)
-				 */
 	struct fsck_inode_ext_record *ext_rec;	/* 4.0: extension record address         */
 };
 
@@ -395,18 +387,6 @@ struct recon_buf_record {
 	char reserved[12];
 };
 
-/*----------------------------------------------------------------------------
- * type treeStack_record describes one stack element used during DASD
- *                         limits processing
- *
- */
-struct treeStack_record {
-	struct fsck_inode_record *inorec;
-	struct treeStack_record *next;
-};
-
-#define treeStack_elem_length sizeof(struct treeStack_record)
-
 /*----------------------------------------------------------------------------
  * structure fsck_agg_record describes the aggregate
  */
@@ -498,7 +478,6 @@ struct fsck_agg_record {
 	UniChar *UniChar_lsfn_name;	/* equiv to lost+found		*/
 	UniChar *UniChar_LSFN_NAME;	/* equiv to LOST+FOUND		*/
 	/* end of unicharacter equivalents	*/
-	int64_t lsfn_dasdused_adjustment;
 	uint32_t lsfn_inonum;	/* inode number of /lost+found/		*/
 	uint32_t avail_inonum;	/* inode number of an inode
 				 * observed to be allocated and not
@@ -536,11 +515,9 @@ struct fsck_agg_record {
 	unsigned warning_pending:1;
 	unsigned high_mem_allocated:1;	/* fourth byte, first nibble	*/
 	unsigned rootdir_rebuilt:1;
-	unsigned active_dasd_limits:1;
 	unsigned stdout_redirected:1;
-	unsigned prime_dasd_limits:1;	/* fourth byte, second nibble	*/
 	unsigned parm_options_logredo_only:1;
-	unsigned unused_4_2:2;
+	unsigned unused_4_2:4;
 	/* end of flag bytes  */
 	int path_buffer_length;	/* length of path_buffer      */
 	char *path_buffer;	/* storage allocated (if any) for
@@ -572,11 +549,6 @@ struct fsck_agg_record {
 								 * entries to be added when reconnecting
 								 * inodes
 								 */
-	struct treeStack_record *treeStack;	/* head of the stack used during tree
-						 * traversal
-						 */
-	struct treeStack_record *free_treeStack;	/* available tree stack elements      */
-	int32_t tree_height;
 	struct dtreeQelem *dtreeQ_front;
 	struct dtreeQelem *dtreeQ_back;
 	struct dtreeQelem *free_dtreeQ;	/* available dtree stack elements        */
