@@ -97,7 +97,7 @@ int Is_Device_Mounted(char *Device_Name)
 	FILE *Mount_Records;	/* Pointer for system's mount records */
 	struct mntent *Mount_Data;	/* Holds data for entry in mount list */
 	int Mounted_RC = 0;	/* Holds return code.             */
-	char Root_FS_Type[] = "0000000";
+	int root_not_jfs = 0;
 
 #define ROOT_DIR "/"
 
@@ -113,9 +113,16 @@ int Is_Device_Mounted(char *Device_Name)
 
 	/* Attempt to find specified device name in mount records */
 	while ((Mount_Data = getmntent(Mount_Records)) != NULL) {
-		/* save root file system type for later, if needed */
-		if (strcmp(ROOT_DIR, Mount_Data->mnt_dir) == 0)
-			strcpy(Root_FS_Type, Mount_Data->mnt_type);
+		/*
+		 * There may be more than one entry for /.  Trust the
+		 * latest one
+		 */
+		if (strcmp(ROOT_DIR, Mount_Data->mnt_dir) == 0) {
+			if (strcmp("jfs", Mount_Data->mnt_type) == 0)
+				root_not_jfs = 0;
+			else
+				root_not_jfs = 1;
+		}
 		if (strcmp(Device_Name, Mount_Data->mnt_fsname) == 0)
 			break;
 	}
@@ -141,8 +148,7 @@ int Is_Device_Mounted(char *Device_Name)
 				 * Make a best effort to ensure that
 				 * the root file system type is jfs
 				 */
-				if ((strcmp(Root_FS_Type, "0000000") != '0') &&
-				    (strcmp(Root_FS_Type, "jfs") != 0))
+				if (root_not_jfs)
 					/* is mounted, found type, is not type jfs */
 					Mounted_RC = MSG_JFS_NOT_JFS;
 			}
