@@ -171,7 +171,7 @@ extern int alloc_wrksp(uint32_t, int, int, void **);	/* defined in fsckwsp.c */
  * forward references
  */
 int open_outfile(void);
-int ldmp_readSuper(int32_t, struct superblock *);
+int ldmp_readSuper(FILE *, struct superblock *);
 int ldmp_isLogging(caddr_t, int32_t, char *, int32_t);
 int ldmp_logError(int, int);
 int usage(void);
@@ -194,7 +194,7 @@ int prtdesc(struct lrd *);
  *
  */
 
-int jfs_logdump(caddr_t pathname, int32_t fd, int32_t dump_all)
+int jfs_logdump(caddr_t pathname, FILE *fp, int32_t dump_all)
 {
 	int rc;
 	int32_t logaddr, nextaddr, lastaddr, nlogrecords;
@@ -217,7 +217,7 @@ int jfs_logdump(caddr_t pathname, int32_t fd, int32_t dump_all)
 		 * Find and open the log
 		 */
 		LogOpenMode = O_RDONLY;
-		rc = findLog(fd, &in_use);
+		rc = findLog(fp, &in_use);
 
 		if (rc < 0) {
 			printf("JFS_LOGDUMP:Error occurred when open/read device\n");
@@ -233,7 +233,7 @@ int jfs_logdump(caddr_t pathname, int32_t fd, int32_t dump_all)
 		 * aggregate block size is for log file as well.
 		 */
 
-		rc = ujfs_rw_diskblocks(Log.fd,
+		rc = ujfs_rw_diskblocks(Log.fp,
 					(uint64_t) (Log.xaddr + LOGPNTOB(LOGSUPER_B)),
 					(unsigned) sizeof (struct logsuper), (char *) &logsup, GET);
 		if (rc != 0) {
@@ -298,7 +298,7 @@ int jfs_logdump(caddr_t pathname, int32_t fd, int32_t dump_all)
 			printf("logend < 0\n");
 			ldmp_logError(LOGEND, 0);
 			ujfs_swap_logsuper(&logsup);
-			rc = ujfs_rw_diskblocks(Log.fd,
+			rc = ujfs_rw_diskblocks(Log.fp,
 						(uint64_t) (Log.xaddr + LOGPNTOB(LOGSUPER_B)),
 						(unsigned long) LOGPSIZE, (char *) &logsup, PUT);
 			rc = logend;
@@ -515,7 +515,7 @@ int jfs_logdump(caddr_t pathname, int32_t fd, int32_t dump_all)
 
 /*----------------------------------------------------------------
  *
- * NAME:        ldmp_readSuper(fd, sb)
+ * NAME:        ldmp_readSuper(fp, sb)
  *
  * FUNCTION:    read the superblock for the file system described
  *              by the file descriptor of the opened aggregate/lv.
@@ -523,7 +523,7 @@ int jfs_logdump(caddr_t pathname, int32_t fd, int32_t dump_all)
  *              try to read the secondary superblock. report error only
  *              when both reads failed.
  */
-int ldmp_readSuper(int32_t fd,	/* file descriptor */
+int ldmp_readSuper(FILE *fp,	/* file descriptor */
 		   struct superblock * sb)
 {				/* superblock of the opened aggregate/lv */
 	int rc;
@@ -543,7 +543,7 @@ int ldmp_readSuper(int32_t fd,	/* file descriptor */
 	/*
 	 * read super block
 	 */
-	rc = ujfs_rw_diskblocks(fd, SUPER1_OFF, (unsigned) SIZE_OF_SUPER, super.block, GET);
+	rc = ujfs_rw_diskblocks(fp, SUPER1_OFF, (unsigned) SIZE_OF_SUPER, super.block, GET);
 	if (rc != 0) {
 		printf
 		    ("ldmp_readSuper: read primary agg superblock failed. errno=%d  Continuing.\n",
@@ -556,7 +556,7 @@ int ldmp_readSuper(int32_t fd,	/* file descriptor */
 		/* read failed for the primary superblock:
 		 * try to read the secondary superblock
 		 */
-		rc = ujfs_rw_diskblocks(fd, SUPER2_OFF, (unsigned) SIZE_OF_SUPER, super.block, GET);
+		rc = ujfs_rw_diskblocks(fp, SUPER2_OFF, (unsigned) SIZE_OF_SUPER, super.block, GET);
 		if (rc != 0) {
 			printf
 			    ("ldmp_readSuper: read 2ndary agg superblock failed. errno=%d  Cannot continue.\n",
