@@ -523,7 +523,7 @@ int bMapRead(int vol,		/* index in vopen array */
 	/*
 	 * read in the map page
 	 */
-	bmr_rc = ujfs_rw_diskblocks(vopen[vol].fd,
+	bmr_rc = ujfs_rw_diskblocks(vopen[vol].fp,
 				    vopen[vol].bmap_wsp[page_number].
 				    page_offset, PSIZE, page_buffer, GET);
 	if (bmr_rc != 0) {
@@ -552,7 +552,7 @@ int bMapWrite(int vol,		/* index in vopen array */
 	/*
 	 * write out the map page
 	 */
-	bmw_rc = ujfs_rw_diskblocks(vopen[vol].fd,
+	bmw_rc = ujfs_rw_diskblocks(vopen[vol].fp,
 				    vopen[vol].bmap_wsp[page_number].
 				    page_offset, PSIZE, page_buffer, PUT);
 	if (bmw_rc != 0) {
@@ -814,7 +814,7 @@ int iMapRead(int vol,		/* index in vopen array */
 	/*
 	 * read in the map page
 	 */
-	imr_rc = ujfs_rw_diskblocks(vopen[vol].fd,
+	imr_rc = ujfs_rw_diskblocks(vopen[vol].fp,
 				    vopen[vol].fsimap_lst.imap_wsp[page_number].page_offset, 
 				    PSIZE, page_buffer, GET);
 	if (imr_rc != 0) {
@@ -843,7 +843,7 @@ int iMapWrite(int vol,		/* index in vopen array */
 	/*
 	 * write out the map page
 	 */
-	imw_rc = ujfs_rw_diskblocks(vopen[vol].fd,
+	imw_rc = ujfs_rw_diskblocks(vopen[vol].fp,
 				    vopen[vol].fsimap_lst.imap_wsp[page_number].page_offset, 
 				    PSIZE, page_buffer, PUT);
 	if (imw_rc != 0) {
@@ -1866,8 +1866,9 @@ int bread(int32_t vol,		/* index in vopen (minor of aggregate)  */
 	  void **buf,		/* set to point to buffer pool page     */
 	  int32_t update)
 {				/* true if buffer will be modified      */
+	FILE *fp;
 	int rc;
-	int32_t k, hash, oldhash, nxt, prv, found, head, fd;
+	int32_t k, hash, oldhash, nxt, prv, found, head;
 	int32_t nblocks, nbytes;
 	int64_t blkno;		/* number of agge. blks in pxd */
 
@@ -1953,9 +1954,9 @@ int bread(int32_t vol,		/* index in vopen (minor of aggregate)  */
 	bufhdr[k].inuse = 1;
 	bufhdr[k].modify = update;
 
-	fd = vopen[vol].fd;
+	fp = vopen[vol].fp;
 	nbytes = nblocks << vopen[vol].l2bsize;
-	rc = ujfs_rw_diskblocks(fd,
+	rc = ujfs_rw_diskblocks(fp,
 				(uint64_t) (blkno << vopen[vol].l2bsize),
 				(unsigned) nbytes, (char *) &buffer[k - 1], GET);
 	if (rc != 0) {
