@@ -239,11 +239,11 @@ int getLogpage(int pno)
 	 */
 	nextrep = (nextrep + 1) % 4;
 	if (Log.location & INLINELOG)
-		rc = ujfs_rw_diskblocks(Log.fd,
+		rc = ujfs_rw_diskblocks(Log.fp,
 					(uint64_t) (Log.xaddr + LOGPNTOB(pno)),
 					(unsigned) LOGPSIZE, (char *) &logp[nextrep], GET);
 	else
-		rc = ujfs_rw_diskblocks(Log.fd,
+		rc = ujfs_rw_diskblocks(Log.fp,
 					(uint64_t) LOGPNTOB(pno),
 					(unsigned) LOGPSIZE, (char *) &logp[nextrep], GET);
 
@@ -324,7 +324,7 @@ int setLogpage(int32_t pno,	/* page number of log           */
 
 	/* if any difference write the page out */
 	if (diff1 || diff2) {
-		rc = ujfs_rw_diskblocks(Log.fd,
+		rc = ujfs_rw_diskblocks(Log.fp,
 					(uint64_t) (Log.xaddr + LOGPNTOB(pno)),
 					(unsigned long) LOGPSIZE, (char *) &logp[buf], PUT);
 		if (rc != 0) {
