@@ -40,7 +40,7 @@
  *		-1 -	error occur 
  *
  */
-int jfs_logform(int fd,		/* this is a file descriptor
+int jfs_logform(FILE *fp,		/* this is a file descriptor
 				 * for an opened device to write log. 
 				 */
 		int aggr_blk_size,	/* aggregate block size in bytes */
@@ -94,7 +94,7 @@ int jfs_logform(int fd,		/* this is a file descriptor
 		log_len_in_bytes = ((int64_t) log_len) << s_l2bsize;
 		npages = log_len_in_bytes / LOGPSIZE;
 	} else {
-		if (ujfs_get_dev_size(fd, &log_len_in_bytes))
+		if (ujfs_get_dev_size(fp, &log_len_in_bytes))
 			return -1;
 
 #define MAX_LOG_SIZE 128*1048576	/* 128 MB */
@@ -111,7 +111,7 @@ int jfs_logform(int fd,		/* this is a file descriptor
 			uuid_generate(uuid);
 		else {
 			/* Verify existing uuid matches uuid passed in */
-			rc = ujfs_rw_diskblocks(fd, (log_begin + LOGPSIZE),
+			rc = ujfs_rw_diskblocks(fp, (log_begin + LOGPSIZE),
 						(unsigned) LOGPSIZE, (char *) log_sup, GET);
 			if (rc)
 				return -1;
@@ -159,7 +159,7 @@ int jfs_logform(int fd,		/* this is a file descriptor
 	/* swap if on big endian machine */
 	ujfs_swap_logsuper(log_sup);
 
-	rc = ujfs_rw_diskblocks(fd, (log_begin + LOGPSIZE),
+	rc = ujfs_rw_diskblocks(fp, (log_begin + LOGPSIZE),
 				(unsigned) LOGPSIZE, (char *) log_sup, PUT);
 	if (rc != 0)
 		return -1;
@@ -214,7 +214,7 @@ int jfs_logform(int fd,		/* this is a file descriptor
 	/* swap if on big endian machine */
 	ujfs_swap_logpage(logp, 2);
 
-	rc = ujfs_rw_diskblocks(fd, (log_begin + 2 * LOGPSIZE),
+	rc = ujfs_rw_diskblocks(fp, (log_begin + 2 * LOGPSIZE),
 				(unsigned) 2 * LOGPSIZE, (char *) &(logp[0]), PUT);
 
 	ujfs_swap_logpage(logp, 2);	/* Swap back */
@@ -255,7 +255,7 @@ int jfs_logform(int fd,		/* this is a file descriptor
 		/* swap if on big endian machine */
 		ujfs_swap_logpage(logp, 4);
 
-		rc = ujfs_rw_diskblocks(fd, log_contwt,
+		rc = ujfs_rw_diskblocks(fp, log_contwt,
 					(unsigned) LOGBUFSIZE, (char *) &(logp[0]), PUT);
 		if (rc != 0)
 			return -1;
@@ -290,8 +290,8 @@ int jfs_logform(int fd,		/* this is a file descriptor
 	}
 
 	if (!inlinelog) {
-		ujfs_flush_dev(fd);
-		close(fd);
+		ujfs_flush_dev(fp);
+		fclose(fp);
 	}
 
 	return (0);
