@@ -18,6 +18,6 @@
 #ifndef H_LOGFORM
 #define H_LOGFORM
 
-int jfs_logform(int, int, int, uint, int64_t, int, uuid_t, char *);
+int jfs_logform(FILE *, int, int, uint, int64_t, int, uuid_t, char *);
 
 #endif				/* H_LORFORM */
