@@ -39,6 +39,7 @@
 #include "logform.h"
 #include "devices.h"
 #include "debug.h"
+#include "utilsubs.h"
 
 #include "fsck_message.h"		/* for chkdsk message logging facility */
 
@@ -105,7 +106,7 @@ struct vopen vopen[MAX_ACTIVE];
 struct log_info Log;
 struct {
 	uuid_t uuid;
-	int fd;
+	FILE *fp;
 } primary_vol;
 extern int LogOpenMode;		/* logdump sets this to O_RDONLY */
 
@@ -177,11 +178,9 @@ extern int doNoRedoPage(struct lrd *);
 extern int doNoRedoInoExt(struct lrd *);
 extern int doAfter(struct lrd *, int32_t);
 extern int doUpdateMap(struct lrd *);
-
-extern int v_fsck_send_msg(int, const char *, int, ...);
 extern int alloc_wrksp(uint32_t, int, int, void **);
 
-extern int open_by_label(uuid_t, int, int, char *, int *);
+extern FILE * open_by_label(uuid_t, int, int, char *, int *);
 extern char log_device[];
 /*
  * forward references
@@ -189,12 +188,12 @@ extern char log_device[];
 int doMount(struct lrd *);
 int openVol(int32_t);
 int updateSuper(int vol);
-int rdwrSuper(int32_t, struct superblock *, int32_t);
+int rdwrSuper(FILE *, struct superblock *, int32_t);
 int bflush(int32_t, struct bufpool *);
 int logOpen(void);
 int fsError(int, int, int64_t);
 int logError(int, int);
-static int recoverExtendFS(int32_t fd);
+static int recoverExtendFS(FILE *);
 int alloc_storage(int32_t, void **, int32_t *);
 int alloc_dmap_bitrec(struct dmap_bitmaps **);
 
@@ -468,7 +467,7 @@ int32_t dflag = 0;
  * if the crash occurs just after writing the super block, the map sizes
  * are fixed up here.
  */
-int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
+int jfs_logredo(caddr_t pathname, FILE *fp, int32_t use_2nd_aggSuper)
 {
 	int rc;
 	int k, logaddr, nextaddr, lastaddr, nlogrecords;
@@ -495,7 +494,7 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 	/*
 	 * validate that the log is not currently in use;
 	 */
-	rc = findLog(fd, &in_use);
+	rc = findLog(fp, &in_use);
 	if (rc < 0) {
 		fsck_send_msg(lrdo_DEVOPNREADERROR);
 		return (rc);
@@ -504,7 +503,7 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 	/* recover from extendfs() ? */
 	if (Log.location & INLINELOG && (vopen[0].status & FM_EXTENDFS)) {
 		fsck_send_msg(lrdo_REXTNDBEGIN);
-		rc = recoverExtendFS(fd);
+		rc = recoverExtendFS(fp);
 		fsck_send_msg(lrdo_REXTNDDONE);
 		return rc;
 	}
@@ -514,7 +513,7 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 	 *
 	 * aggregate block size is for log file as well.
 	 */
-	rc = ujfs_rw_diskblocks(Log.fd,
+	rc = ujfs_rw_diskblocks(Log.fp,
 				(uint64_t) (Log.xaddr +
 					    LOGPNTOB(LOGSUPER_B)),
 				(unsigned) sizeof (struct logsuper), (char *) &logsup, GET);
@@ -540,7 +539,7 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 	if (Log.location & OUTLINELOG) {
 		struct stat st;
 
-		if ((rc = fstat(Log.fd, &st)))
+		if ((rc = fstat(fileno(Log.fp), &st)))
 			goto error_out;
 
 		Log.devnum = st.st_rdev;
@@ -575,7 +574,7 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 		fsck_send_msg(lrdo_LOGENDBAD1);
 		logError(LOGEND, 0);
 		ujfs_swap_logsuper(&logsup);
-		rc = ujfs_rw_diskblocks(Log.fd,
+		rc = ujfs_rw_diskblocks(Log.fp,
 					(Log.xaddr + LOGPNTOB(LOGSUPER_B)),
 					(unsigned long) LOGPSIZE, (char *) &logsup, PUT);
 		rc = logend;
@@ -791,7 +790,7 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 		/* Make sure all changes are committed to disk before we
 		 * mark the superblock clean
 		 */
-		fsync(vopen[k].fd);
+		ujfs_flush_dev(vopen[k].fp);
 
 		if ((rc = updateSuper(k)) != 0) {
 			fsck_send_msg(lrdo_ERRORCANTUPDFSSUPER);
@@ -799,7 +798,7 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 		}
 
 		/* sync superblock before journal is finalized */
-		fsync(vopen[k].fd);
+		ujfs_flush_dev(vopen[k].fp);
 	}
 
 	/*
@@ -819,7 +818,7 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 		logsup.magic = LOGMAGIC;
 	}
 	ujfs_swap_logsuper(&logsup);
-	rc = ujfs_rw_diskblocks(Log.fd, (Log.xaddr + LOGPNTOB(LOGSUPER_B)),
+	rc = ujfs_rw_diskblocks(Log.fp, (Log.xaddr + LOGPNTOB(LOGSUPER_B)),
 				LOGPSIZE, (char *) &logsup, PUT);
 
 	/*
@@ -897,17 +896,17 @@ int openVol(int vol)
 	if (Log.location & OUTLINELOG) {
 		/* First check if this is the already opened volume */
 		if (!uuid_compare(vopen[vol].uuid, primary_vol.uuid))
-			vopen[vol].fd = primary_vol.fd;
+			vopen[vol].fp = primary_vol.fp;
 		else {
-			vopen[vol].fd = open_by_label(vopen[vol].uuid, 0, 0,
+			vopen[vol].fp = open_by_label(vopen[vol].uuid, 0, 0,
 						      NULL, NULL);
-			if (vopen[vol].fd < 0)
+			if (vopen[vol].fp == NULL)
 				return ENOENT;
 		}
 	}
 
 	/* read superblock of the aggregate/volume */
-	if ((rc = rdwrSuper(vopen[vol].fd, &sb, PB_READ)) != 0) {
+	if ((rc = rdwrSuper(vopen[vol].fp, &sb, PB_READ)) != 0) {
 		fsck_send_msg(lrdo_CANTREADFSSUPER);
 
 		fsError(READERR, vol, SUPER1_B);
@@ -1023,7 +1022,7 @@ int updateSuper(int vol)
 	struct superblock sb;
 
 	/* read in superblock of the volume */
-	if ((rc = rdwrSuper(vopen[vol].fd, &sb, PB_READ)) != 0) {
+	if ((rc = rdwrSuper(vopen[vol].fp, &sb, PB_READ)) != 0) {
 		fsck_send_msg(lrdo_READFSSUPERFAIL);
 		return (FSSUPER_READERROR2);
 	}
@@ -1035,7 +1034,7 @@ int updateSuper(int vol)
 	else
 		sb.s_state = FM_CLEAN;
 
-	if ((rc = rdwrSuper(vopen[vol].fd, &sb, PB_UPDATE)) != 0) {
+	if ((rc = rdwrSuper(vopen[vol].fp, &sb, PB_UPDATE)) != 0) {
 		fsck_send_msg(lrdo_WRITEFSSUPERFAIL);
 	}
 
@@ -1043,7 +1042,7 @@ int updateSuper(int vol)
 }
 
 /*
- * NAME:        rdwrSuper(fd, sb, rwflag)
+ * NAME:        rdwrSuper(fp, sb, rwflag)
  *
  * FUNCTION:    read or write the superblock for the file system described
  *              by the file descriptor of the opened aggregate/lv.
@@ -1052,7 +1051,7 @@ int updateSuper(int vol)
  *              when both reads failed.
  *              for write, any write failure should be reported.
  */
-int rdwrSuper(int32_t fd, struct superblock * sb, int32_t rwflag)
+int rdwrSuper(FILE *fp, struct superblock * sb, int32_t rwflag)
 {
 	int rc;
 	uint64_t super_offset;
@@ -1077,7 +1076,7 @@ int rdwrSuper(int32_t fd, struct superblock * sb, int32_t rwflag)
 	 * read super block
 	 */
 	if (rwflag == PB_READ) {
-		rc = ujfs_rw_diskblocks(fd, super_offset,
+		rc = ujfs_rw_diskblocks(fp, super_offset,
 					(unsigned) SIZE_OF_SUPER, super.block, GET);
 		if (rc != 0) {
 			if (!use_2ndary_agg_superblock) {
@@ -1106,7 +1105,7 @@ int rdwrSuper(int32_t fd, struct superblock * sb, int32_t rwflag)
 		 * write whichever superblock we're working with.
 		 * chkdsk will take care of replicating it.
 		 */
-		rc = ujfs_rw_diskblocks(fd, super_offset,
+		rc = ujfs_rw_diskblocks(fp, super_offset,
 					(unsigned) SIZE_OF_SUPER, super.block, PUT);
 		if (rc != 0) {
 			if (!use_2ndary_agg_superblock) {
@@ -1132,8 +1131,9 @@ int rdwrSuper(int32_t fd, struct superblock * sb, int32_t rwflag)
 int bflush(int32_t k,		/*  The index in bufhdr that describes buf */
 	   struct bufpool *buf)
 {				/* pointer to buffer pool page */
+	FILE *fp = NULL;
 	int rc;
-	int32_t fd, vol;
+	int32_t vol;
 	int32_t nbytes;
 	int64_t blkno;
 
@@ -1143,10 +1143,10 @@ int bflush(int32_t k,		/*  The index in bufhdr that describes buf */
 
 	/* write it out */
 	vol = bufhdr[k].vol;
-	fd = vopen[vol].fd;
+	fp = vopen[vol].fp;
 	blkno = addressPXD(&bufhdr[k].pxd);
 	nbytes = lengthPXD(&bufhdr[k].pxd) << vopen[vol].l2bsize;
-	rc = ujfs_rw_diskblocks(fd,
+	rc = ujfs_rw_diskblocks(fp,
 				(uint64_t) (blkno << vopen[vol].l2bsize),
 				(unsigned) nbytes, (char *) buf, PUT);
 	if (rc != 0) {
@@ -1168,7 +1168,7 @@ int bflush(int32_t k,		/*  The index in bufhdr that describes buf */
  * 		the log device.
  *
  */
-int findLog(int fd, int *in_use)
+int findLog(FILE *fp, int *in_use)
 {
 	struct logsuper logsup;
 	struct superblock sb;
@@ -1177,7 +1177,7 @@ int findLog(int fd, int *in_use)
 	/*
 	 * try the LV as file system with in-line log
 	 */
-	if (rdwrSuper(fd, &sb, PB_READ)) {
+	if (rdwrSuper(fp, &sb, PB_READ)) {
 		fsck_send_msg(lrdo_NOTAFSDEV);
 		return NOT_FSDEV_ERROR;
 	}
@@ -1191,19 +1191,19 @@ int findLog(int fd, int *in_use)
 		 */
 		if ((sb.s_flag & JFS_INLINELOG) == JFS_INLINELOG) {
 			Log.location = INLINELOG;
-			Log.fd = fd;
+			Log.fp = fp;
 			//Log.status = sb.s_state;
 			Log.l2bsize = sb.s_l2bsize;
 			Log.xaddr = addressPXD(&sb.s_logpxd) << sb.s_l2bsize;
 
 			/* vopen[0] represents fs if inline log */
 			vopen[0].status = sb.s_state;
-			vopen[0].fd = fd;
+			vopen[0].fp = fp;
 
 			return 0;
 		}
-		/* Save fd and uuid */
-		primary_vol.fd = fd;
+		/* Save fp and uuid */
+		primary_vol.fp = fp;
 		uuid_copy(primary_vol.uuid, sb.s_uuid);
 
 		/*
@@ -1214,21 +1214,25 @@ int findLog(int fd, int *in_use)
 		 */
 		Log.xaddr = 0;
 		if (log_device[0]) {
-			Log.fd = open(log_device, LogOpenMode, 0);
-			if (Log.fd < 0) {
-				Log.fd = open(log_device, O_RDONLY, 0);
-				if (Log.fd < 0) {
+			Log.fp = NULL;
+			if (LogOpenMode != O_RDONLY) {
+				Log.fp = fopen_excl(log_device, "r+");
+				if (Log.fp == NULL)
+					*in_use = 1;
+			}
+			if (Log.fp == NULL) {
+				Log.fp = fopen(log_device, "r");
+				if (Log.fp == NULL) {
 					printf("Invalid journal specified (%s)\n",
 					       log_device);
 					goto by_uuid;
 				}
-				*in_use = 1;
 			}
-			ujfs_rw_diskblocks(Log.fd, LOGPNTOB(LOGSUPER_B),
+			ujfs_rw_diskblocks(Log.fp, LOGPNTOB(LOGSUPER_B),
 					   sizeof (struct logsuper), &logsup, GET);
 			ujfs_swap_logsuper(&logsup);
 			if ((logsup.magic != LOGMAGIC) || (uuid_compare(logsup.uuid, sb.s_loguuid))) {
-				close(Log.fd);
+				fclose(Log.fp);
 				*in_use = 0;
 				goto by_uuid;
 			}
@@ -1236,9 +1240,9 @@ int findLog(int fd, int *in_use)
 			return 0;
 		}
 	      by_uuid:
-		Log.fd = open_by_label(sb.s_loguuid, 0, 1, NULL, in_use);
+		Log.fp = open_by_label(sb.s_loguuid, 0, 1, NULL, in_use);
 
-		if (Log.fd >= 0) {
+		if (Log.fp != NULL) {
 			Log.location |= OUTLINELOG;
 			return 0;
 		}
@@ -1248,13 +1252,13 @@ int findLog(int fd, int *in_use)
 	/*
 	 * is this an external log?
 	 */
-	ujfs_rw_diskblocks(fd, LOGPNTOB(LOGSUPER_B), sizeof (struct logsuper), &logsup, GET);
+	ujfs_rw_diskblocks(fp, LOGPNTOB(LOGSUPER_B), sizeof (struct logsuper), &logsup, GET);
 	ujfs_swap_logsuper(&logsup);
 	if (logsup.magic != LOGMAGIC) {
 		fsck_send_msg(lrdo_NOTAFSDEV);
 		return NOT_FSDEV_ERROR;
 	}
-	Log.fd = fd;
+	Log.fp = fp;
 	Log.location = OUTLINELOG;
 
 	return 0;
@@ -1353,9 +1357,9 @@ int logError(int type, int logaddr)
  * unknown state;
  *
  * at entry, only log type/lv has been validated;
- * for inline log: vopen[0], fs fd = log fd;
+ * for inline log: vopen[0], fs fp = log fp;
  */
-static int recoverExtendFS(int32_t fd)
+static int recoverExtendFS(FILE *fp)
 {
 	struct superblock *sbp;
 	struct dinode *dip1, *dip2;
@@ -1372,12 +1376,12 @@ static int recoverExtendFS(int32_t fd)
 	 */
 	/* read superblock yet again */
 	sbp = (struct superblock *) &buffer[0];
-	if (rdwrSuper(fd, sbp, PB_READ))
+	if (rdwrSuper(fp, sbp, PB_READ))
 		goto errout;
 
 	/* read primary block allocation map inode */
 	dip = (char *) &buffer[1];
-	if (ujfs_rw_diskblocks(fd, AITBL_OFF, PSIZE, dip, GET)) {
+	if (ujfs_rw_diskblocks(fp, AITBL_OFF, PSIZE, dip, GET)) {
 		fsck_send_msg(lrdo_EXTFSREADFSSUPERFAIL);
 		goto errout;
 	}
@@ -1398,7 +1402,7 @@ static int recoverExtendFS(int32_t fd)
 	do {
 		/* read in the leftmost child page */
 		t64 = addressXAD(&p->xad[XTENTRYSTART]) << sbp->s_l2bsize;
-		if (ujfs_rw_diskblocks(fd, t64, PSIZE, bp, GET)) {
+		if (ujfs_rw_diskblocks(fp, t64, PSIZE, bp, GET)) {
 			fsck_send_msg(lrdo_EXTFSREADBLKMAPINOFAIL);
 			goto errout;
 		}
@@ -1411,7 +1415,7 @@ static int recoverExtendFS(int32_t fd)
 
       rdbgcp:
 	t64 = addressXAD(&p->xad[XTENTRYSTART]) << sbp->s_l2bsize;
-	if (ujfs_rw_diskblocks(fd, t64, PSIZE, bp, GET)) {
+	if (ujfs_rw_diskblocks(fp, t64, PSIZE, bp, GET)) {
 		fsck_send_msg(lrdo_EXTFSREADBLKFAIL1, (long long) t64);
 		goto errout;
 	}
@@ -1433,7 +1437,7 @@ static int recoverExtendFS(int32_t fd)
 	 */
 	/* read 2ndary block allocation map inode */
 	t64 = addressPXD(&sbp->s_ait2) << sbp->s_l2bsize;
-	if (ujfs_rw_diskblocks(fd, t64, PSIZE, bp, GET)) {
+	if (ujfs_rw_diskblocks(fp, t64, PSIZE, bp, GET)) {
 		fsck_send_msg(lrdo_EXTFSREADBLKFAIL2, (long long) t64);
 		goto errout;
 	}
@@ -1450,7 +1454,7 @@ static int recoverExtendFS(int32_t fd)
 	memcpy(dip1, dip2, DISIZE);
 	memcpy((void *) &(dip1->di_ixpxd), (void *) &temp_pxd, sizeof (pxd_t));
 
-	if (ujfs_rw_diskblocks(fd, AITBL_OFF, PSIZE, dip, PUT)) {
+	if (ujfs_rw_diskblocks(fp, AITBL_OFF, PSIZE, dip, PUT)) {
 		fsck_send_msg(lrdo_EXTFSWRITEBLKFAIL1, AITBL_OFF);
 		goto errout;
 	}
@@ -1502,7 +1506,7 @@ static int recoverExtendFS(int32_t fd)
 					 * pages
 					 */
 					p->header.next = 0;
-					if (ujfs_rw_diskblocks(fd, t64, PSIZE, p, PUT)) {
+					if (ujfs_rw_diskblocks(fp, t64, PSIZE, p, PUT)) {
 						fsck_send_msg(lrdo_EXTFSWRITEBLKFAIL2, (long long) t64);
 						goto errout;
 					}
@@ -1518,14 +1522,14 @@ static int recoverExtendFS(int32_t fd)
 			if (xaddr) {
 				if (xaddr >= barrier) {
 					p->header.next = 0;
-					if (ujfs_rw_diskblocks(fd, t64, PSIZE, p, PUT)) {
+					if (ujfs_rw_diskblocks(fp, t64, PSIZE, p, PUT)) {
 						fsck_send_msg(lrdo_EXTFSWRITEBLKFAIL3, (long long) t64);
 						break;
 					}
 				}
 
 				t64 = xaddr << sbp->s_l2bsize;
-				if (ujfs_rw_diskblocks(fd, t64, PSIZE, bp, GET)) {
+				if (ujfs_rw_diskblocks(fp, t64, PSIZE, bp, GET)) {
 					fsck_send_msg(lrdo_EXTFSREADBLKFAIL3, (long long) t64);
 					goto errout;
 				}
@@ -1543,7 +1547,7 @@ static int recoverExtendFS(int32_t fd)
 			/* get the leftmost child page  */
 			xaddr = lmchild;
 			t64 = xaddr << sbp->s_l2bsize;
-			if (ujfs_rw_diskblocks(fd, t64, PSIZE, bp, GET)) {
+			if (ujfs_rw_diskblocks(fp, t64, PSIZE, bp, GET)) {
 				fsck_send_msg(lrdo_EXTFSREADBLKFAIL4, (long long) t64);
 				goto errout;
 			}
@@ -1589,7 +1593,7 @@ static int recoverExtendFS(int32_t fd)
 	 * request reformat original log  (which might have been
 	 * overwritten by extendfs() and set superblock clean
 	 */
-	jfs_logform(fd, sbp->s_bsize, sbp->s_l2bsize, sbp->s_flag,
+	jfs_logform(fp, sbp->s_bsize, sbp->s_l2bsize, sbp->s_flag,
 		    addressPXD(&sbp->s_logpxd), lengthPXD(&sbp->s_logpxd), NULL, NULL);
 
 	/* update superblock */
@@ -1608,7 +1612,7 @@ static int recoverExtendFS(int32_t fd)
 	 */
 	/* read 2ndary block allocation map inode */
 	t64 = addressPXD(&sbp->s_ait2) << sbp->s_l2bsize;
-	if (ujfs_rw_diskblocks(fd, t64, PSIZE, bp, GET)) {
+	if (ujfs_rw_diskblocks(fp, t64, PSIZE, bp, GET)) {
 		fsck_send_msg(lrdo_EXTFSREADBLKFAIL5, (long long) t64);
 		goto errout;
 	}
@@ -1624,7 +1628,7 @@ static int recoverExtendFS(int32_t fd)
 	memcpy(dip2, dip1, DISIZE);
 	memcpy((void *) &(dip2->di_ixpxd), (void *) &temp_pxd, sizeof (pxd_t));
 
-	if (ujfs_rw_diskblocks(fd, t64, PSIZE, bp, PUT)) {
+	if (ujfs_rw_diskblocks(fp, t64, PSIZE, bp, PUT)) {
 		fsck_send_msg(lrdo_EXTFSWRITEBLKFAIL4, (long long) t64);
 		goto errout;
 	}
@@ -1643,7 +1647,7 @@ static int recoverExtendFS(int32_t fd)
 	sbp->s_logpxd = sbp->s_xlogpxd;
 	sbp->s_logserial = 1;
 
-	if (rdwrSuper(fd, sbp, PB_UPDATE)) {
+	if (rdwrSuper(fp, sbp, PB_UPDATE)) {
 		fsck_send_msg(lrdo_EXTFSWRITEFSSUPERFAIL);
 		goto errout;
 	}
@@ -1655,7 +1659,7 @@ static int recoverExtendFS(int32_t fd)
 	 */
 	/* read log superblock */
 	t64 = (addressPXD(&sbp->s_logpxd) << sbp->s_l2bsize) + LOGPSIZE;
-	if (ujfs_rw_diskblocks(fd, t64, LOGPSIZE, &logsup, GET)) {
+	if (ujfs_rw_diskblocks(fp, t64, LOGPSIZE, &logsup, GET)) {
 		fsck_send_msg(lrdo_EXTFSREADLOGSUPFAIL);
 		goto errout;
 	}
@@ -1663,7 +1667,7 @@ static int recoverExtendFS(int32_t fd)
 	logsup.end = findEndOfLog();
 	logsup.state = LOGREDONE;
 
-	if (ujfs_rw_diskblocks(fd, t64, LOGPSIZE, &logsup, PUT)) {
+	if (ujfs_rw_diskblocks(fp, t64, LOGPSIZE, &logsup, PUT)) {
 		fsck_send_msg(lrdo_EXTFSWRITELOGSUPFAIL);
 		goto errout;
 	}
