@@ -24,10 +24,10 @@ struct superblock;
 struct logsuper;
 
 extern int ujfs_validate_super(struct superblock *);
-extern int ujfs_put_superblk(int, struct superblock *, int16_t);
-extern int ujfs_get_superblk(int, struct superblock *, int32_t);
-extern int ujfs_put_logsuper(int, struct logsuper *);
-extern int ujfs_get_logsuper(int, struct logsuper *);
+extern int ujfs_put_superblk(FILE *, struct superblock *, int16_t);
+extern int ujfs_get_superblk(FILE *, struct superblock *, int32_t);
+extern int ujfs_put_logsuper(FILE *, struct logsuper *);
+extern int ujfs_get_logsuper(FILE *, struct logsuper *);
 extern int inrange(uint32_t, uint32_t, uint32_t);
 
 #endif
