@@ -1,5 +1,5 @@
 /*
- *   Copyright (c) International Business Machines  Corp., 2000
+ *   Copyright (c) International Business Machines Corp., 2000-2002
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -18,6 +18,9 @@
 #ifndef _H_UJFS_UTILSUBS
 #define _H_UJFS_UTILSUBS
 
+#include <stdio.h>
+#include <fcntl.h>
+
 /*
  *	utilsubs.h
  */
@@ -25,11 +28,19 @@
 /*
  *	function prototypes
  */
-void countLZ32(int32_t word, int32_t *lzero);
-void countTZ32(int32_t word, int32_t *tzero);
-int32_t  log2shift(uint32_t	n);
-
+int32_t log2shift(uint32_t n);
 char prompt(char *str);
-int32_t  more(void);
+int more(void);
 
-#endif	/* _H_UJFS_UTILSUBS */
+static inline FILE *fopen_excl(const char *path, const char *mode)
+{
+	int fd;
+
+	/* Yeah, mode is ignored, we only use this to open for read/write */
+	fd = open(path, O_RDWR | O_EXCL, 0);
+	if (fd < 0)
+		return NULL;
+	return fdopen(fd, mode);
+}
+
+#endif				/* _H_UJFS_UTILSUBS */
