@@ -58,7 +58,7 @@ struct xtree_buf {
 
 static struct xtree_buf *badblock_pages;
 
-static int xtAppend(int, struct dinode *, int64_t, int64_t, int,
+static int xtAppend(FILE *, struct dinode *, int64_t, int64_t, int,
 		    struct xtree_buf *, int);
 
 /*--------------------------------------------------------------------
@@ -84,7 +84,7 @@ static int xtAppend(int, struct dinode *, int64_t, int64_t, int,
  *
  * RETURNS: NONE
  */
-static int initdmap(int dev_ptr, int64_t blkno, int64_t nblocks,
+static int initdmap(FILE *dev_ptr, int64_t blkno, int64_t nblocks,
 		    int8_t * treemax, int64_t start)
 {
 	int rc = 0;
@@ -194,7 +194,7 @@ static int initdmap(int dev_ptr, int64_t blkno, int64_t nblocks,
  *
  * RETURNS: None.
  */
-static int initctl(int dev_ptr,
+static int initctl(FILE *dev_ptr,
 		   int64_t blkno,
 		   int64_t nblocks,
 		   int level, 
@@ -309,7 +309,7 @@ static int initctl(int dev_ptr,
  *
  * RETURNS:
  */
-static int initbmap(int dev_ptr, int64_t nblocks)
+static int initbmap(FILE *dev_ptr, int64_t nblocks)
 {
 	int level, rc = 0;
 	int64_t next_page;
@@ -636,7 +636,7 @@ int markit(int block, unsigned flag)
  *
  * RETURNS: 0 for success
  */
-int write_block_map(int dev_ptr, int64_t number_of_blocks, int aggr_block_size)
+int write_block_map(FILE *dev_ptr, int64_t number_of_blocks, int aggr_block_size)
 {
 	int rc = 0;
 
@@ -673,7 +673,7 @@ int write_block_map(int dev_ptr, int64_t number_of_blocks, int aggr_block_size)
  *
  * RETURNS: 0 for success; Other indicates failure
  */
-static int dbAlloc(int dev_ptr, int64_t xlen, int64_t * xaddr)
+static int dbAlloc(FILE *dev_ptr, int64_t xlen, int64_t * xaddr)
 {
 	int rc = 0;
 	int page, word;
@@ -783,7 +783,7 @@ static int dbAlloc(int dev_ptr, int64_t xlen, int64_t * xaddr)
  *
  * RETURNS: 0 for success; Other indicates failure
  */
-static int xtSplitRoot(int dev_ptr,
+static int xtSplitRoot(FILE *dev_ptr,
 		       struct dinode *ip,
 		       struct xtree_buf *xroot,
 		       int64_t offset, int nblocks, int64_t blkno)
@@ -888,7 +888,7 @@ static int xtSplitPage(struct dinode *ip,
 		       struct xtree_buf *xpage,
 		       int64_t offset,
 		       int nblocks,
-		       int64_t blkno, int dev_ptr, int aggr_block_size)
+		       int64_t blkno, FILE *dev_ptr, int aggr_block_size)
 {
 	int rc = 0;
 	int64_t xaddr;		/* new right page block number */
@@ -971,7 +971,7 @@ static int xtSplitPage(struct dinode *ip,
  *
  * RETURNS: 0 for success; Other indicates failure
  */
-static int xtAppend(int dev_ptr,
+static int xtAppend(FILE *dev_ptr,
 		    struct dinode *di,
 		    int64_t offset,
 		    int64_t blkno,
@@ -1034,7 +1034,7 @@ static int xtAppend(int dev_ptr,
  *
  * RETURNS: 0 for success; Other indicates failure
  */
-static int add_bad_block(int dev_ptr, int64_t thisblk, int aggr_block_size,
+static int add_bad_block(FILE *dev_ptr, int64_t thisblk, int aggr_block_size,
 			 struct dinode *bb_inode)
 {
 	int rc = 0;
@@ -1079,7 +1079,7 @@ static int add_bad_block(int dev_ptr, int64_t thisblk, int aggr_block_size,
 static char *msg_parms[MAXPARMS];
 static char msgstr[MAXSTR];
 
-int verify_last_blocks(int dev_ptr, int aggr_block_size,
+int verify_last_blocks(FILE *dev_ptr, int aggr_block_size,
 		       struct dinode *bb_inode)
 {
 	int rc = 0;
@@ -1108,7 +1108,15 @@ int verify_last_blocks(int dev_ptr, int aggr_block_size,
 
 	/* Allocate and clear a buffer */
 	while ((bufsize >= aggr_block_size) &&
+#ifdef HAVE_POSIX_MEMALIGN
 	       posix_memalign(&buffer, aggr_block_size, bufsize))
+#else
+#ifdef HAVE_MEMALIGN
+			(buffer = memalign(aggr_block_size, bufsize)))
+#else
+			(buffer = valloc(bufsize)))
+#endif
+#endif
 		bufsize >>= 1;
 
 	if (buffer == NULL) {
@@ -1121,8 +1129,8 @@ int verify_last_blocks(int dev_ptr, int aggr_block_size,
 	/*
 	 * Must do direct-io to avoid the page cache
 	 */
-	flags = fcntl(dev_ptr, F_GETFL);
-	fcntl(dev_ptr, F_SETFL, flags | O_DIRECT);
+	flags = fcntl(fileno(dev_ptr), F_GETFL);
+	fcntl(fileno(dev_ptr), F_SETFL, flags | O_DIRECT);
 
 	/*
 	 * Starting from the last allocated block to the end of the aggregate 
@@ -1187,7 +1195,7 @@ int verify_last_blocks(int dev_ptr, int aggr_block_size,
 
 				if (error != 0) {
 					/* add_bad_block may do unaligned I/O */
-					fcntl(dev_ptr, F_SETFL, flags);
+					fcntl(fileno(dev_ptr), F_SETFL, flags);
 
 					/* Add this block to bad list */
 					if ((rc =
@@ -1196,7 +1204,7 @@ int verify_last_blocks(int dev_ptr, int aggr_block_size,
 							   bb_inode)))
 						continue;
 					write_inode = true;
-					fcntl(dev_ptr, F_SETFL,
+					fcntl(fileno(dev_ptr), F_SETFL,
 					      flags | O_DIRECT);
 
 					/*
@@ -1227,7 +1235,7 @@ int verify_last_blocks(int dev_ptr, int aggr_block_size,
 			nblocks -= nb;
 		}
 	}
-	fcntl(dev_ptr, F_SETFL, flags);
+	fcntl(fileno(dev_ptr), F_SETFL, flags);
 
 	msg_parms[0] = "100";
 	message_user(MSG_OSO_PERCENT_FORMAT, msg_parms, 1, OSO_MSG);
