@@ -25,7 +25,7 @@
 int calc_map_size(int64_t, struct dinode *, int, int *, unsigned);
 int markit(int, unsigned);
 int record_LVM_BadBlks( int, int, int, struct dinode *, int64_t );
-int verify_last_blocks( int, int, struct dinode * );
-int write_block_map(int, int64_t, int);
+int verify_last_blocks( FILE *, int, struct dinode * );
+int write_block_map(FILE *, int64_t, int);
 
 #endif	/* H_INITMAP */
