@@ -138,7 +138,7 @@ static int init_AG_free_list(int aggr_block_size,
  *	failure: any other value
  */
 int init_inode_map(int aggr_block_size,
-		   int dev_ptr,
+		   FILE *dev_ptr,
 		   int64_t inode_table_loc,
 		   int inode_table_size,
 		   int64_t inode_map_loc,
