@@ -20,6 +20,6 @@
 
 #include "devices.h"
 
-int init_inode_map(int, int, int64_t, int, int64_t, int, unsigned short, int, unsigned);
+int init_inode_map(int, FILE *, int64_t, int, int64_t, int, unsigned short, int, unsigned);
 
 #endif
