@@ -20,7 +20,9 @@
 #include <fcntl.h>
 #include <unistd.h>
 #include <sys/stat.h>
+#if !defined(__DragonFly__)
 #include <sys/sysmacros.h>
+#endif
 #include <jfs_types.h>
 #include <errno.h>
 #include <string.h>
@@ -42,12 +44,14 @@
 #include "message.h"
 #include "debug.h"
 #include "jfs_version.h"
+#include "utilsubs.h"
 
 unsigned type_jfs;
 char *program_name;
 
 extern int LogOpenMode;
 extern int Is_Device_Mounted(char *);
+FILE *open_by_label(uuid_t, int, int, char *, int *);
 
 static int AGsize;
 
@@ -108,7 +112,7 @@ void mkfs_usage()
  *      success: 0
  *      failure: any other value
  */
-static int create_fileset(int dev_ptr, int aggr_block_size,
+static int create_fileset(FILE *dev_ptr, int aggr_block_size,
 			  int64_t start_block, unsigned inostamp)
 {
 	int rc;
@@ -191,7 +195,7 @@ static int create_fileset(int dev_ptr, int aggr_block_size,
  *      success: 0
  *      failure: any other value
  */
-static int create_aggregate(int dev_ptr,
+static int create_aggregate(FILE *dev_ptr,
 			    char *volume_label,
 			    int64_t number_of_blocks,
 			    int aggr_block_size,
@@ -543,37 +547,6 @@ static int create_aggregate(int dev_ptr,
 	return rc;
 }
 
-/*--------------------------------------------------------------------
- * NAME: Bad_Device
- *
- * FUNCTION: Determine if the device specified is valid for formatting
- *
- * PRE CONDITIONS: Device_Handle must refer to an open device
- *
- * PARAMETERS: Device_Handle - This is a handle to the device that is
- *                             to be formatted
- *
- * RETURNS:
- *      success: 0
- *      failure: any other value
- */
-static int Bad_Device(int Device_Handle)
-{
-
-	struct stat stat_data;
-	int rc;
-
-	rc = fstat(Device_Handle, &stat_data);
-	if (rc)
-		return -1;
-
-	/* Do we have a block special device or regular file? */
-	if (!S_ISBLK(stat_data.st_mode) && !S_ISREG(stat_data.st_mode))
-		return -1;
-
-	return 0;
-}
-
 /*--------------------------------------------------------------------
  * NAME: parse_journal_opts
  *
@@ -590,7 +563,7 @@ void parse_journal_opts(const char *opts, int *ext_journal_opt,
 			char *journal_device)
 {
 	int journal_usage = 0;
-	int log_fd = -1;
+	FILE *log_fd = NULL;
 	uuid_t log_uuid;
 	int in_use;
 
@@ -616,8 +589,8 @@ void parse_journal_opts(const char *opts, int *ext_journal_opt,
 				 * purposes, we do not yet need that file to be 
 				 * open, so close it here.
 				 */
-				if (log_fd >= 0) {
-					close(log_fd);
+				if (log_fd == NULL) {
+					fclose(log_fd);
 				} else {
 					fprintf(stderr,
 						"\nError: Could not find/open device specified by UUID %s.\n",
@@ -635,8 +608,8 @@ void parse_journal_opts(const char *opts, int *ext_journal_opt,
 			 * to an open file.  For jfs_mkfs purposes, we do not yet
 			 * need that file to be open, so close it here.
 			 */
-			if (log_fd >= 0) {
-				close(log_fd);
+			if (log_fd == NULL) {
+				fclose(log_fd);
 			} else {
 				fprintf(stderr,
 					"\nError: Could not find/open device specified by LABEL %s.\n",
@@ -699,9 +672,9 @@ int main(int argc, char *argv[])
 	int64_t number_of_blocks, logloc = 0, logsize_in_bytes = 0;
 	int64_t requested_blocks = 0;
 	char logdev[255] = { '\0' };	/* Need to use a macro for this size */
-	int aggr_block_size = 0;
+	int aggr_block_size = PSIZE;	/* 4096 */
 	int phys_block_size = PBSIZE, logsize = 0;
-	int dev_handle;
+	FILE *dev_handle;
 	unsigned type_commit = JFS_GROUPCOMMIT;
 	bool verify_blocks = false;
 	bool no_questions_asked = false;
@@ -805,11 +778,12 @@ int main(int argc, char *argv[])
 	 */
 	if (ext_journal_opt == create_journal_only) {
 		strcpy(logdev, argv[optind]);
+		goto format_journal;
 	}
 
 	optind++;
 	if (optind < argc)
-		requested_blocks = atoll(argv[optind]);
+		requested_blocks = strtoll(argv[optind], (char **)NULL, 10);
 
 	/* Check for block device */
 	{
@@ -822,7 +796,7 @@ int main(int argc, char *argv[])
 			return EINVAL;
 		}
 		/* Do we have a block special device or regular file? */
-		if (!S_ISBLK(stat_data.st_mode) && !S_ISREG(stat_data.st_mode))
+		if (ujfs_device_is_valid(NULL, &stat_data))
 		{
 			msg_parms[0] = device_name;
 			message_user(MSG_OSO_NOT_VALID_BLOCK_DEVICE,
@@ -842,23 +816,18 @@ int main(int argc, char *argv[])
 	 * Open the device and lock it from all others
 	 * Get the physical block size of the device.
 	 */
-	dev_handle = open(device_name, O_RDWR | O_EXCL, 0);
-	if (dev_handle < 0) {
+	dev_handle = fopen_excl(device_name, "r+");
+	if (dev_handle == NULL) {
 		printf("\nError: Cannot open device %s.\n", device_name);
 		return (ERROR_FILE_NOT_FOUND);
 	}
 
-	if (Bad_Device(dev_handle)) {
+	if (ujfs_device_is_valid(dev_handle, NULL) != 0) {
 		message_user(MSG_OSO_DISK_LOCKED, NULL, 0, OSO_MSG);
 		return (ERROR_FILE_NOT_FOUND);
 	}
 
-	/*
-	 * Check if aggr_block_size was specified.  If not, we make it 4K.
-	 */
-	if (aggr_block_size == 0) {
-		aggr_block_size = PSIZE;	/* 4096 */
-	} else if (aggr_block_size < phys_block_size) {
+	if (aggr_block_size < phys_block_size) {
 		/*
 		 * Make sure the aggr_block_size is not smaller than the 
 		 * logical volume block size.
@@ -868,7 +837,7 @@ int main(int argc, char *argv[])
 		msg_parms[1] = "BS";
 		message_user(MSG_OSO_VALUE_NOT_ALLOWED, msg_parms, 2, OSO_MSG);
 		rc = EINVAL;
-		close(dev_handle);
+		fclose(dev_handle);
 		return (rc);
 	} else {
 		/*
@@ -881,7 +850,7 @@ int main(int argc, char *argv[])
 			message_user(MSG_OSO_VALUE_NOT_ALLOWED, msg_parms, 2,
 				     OSO_MSG);
 			rc = EINVAL;
-			close(dev_handle);
+			fclose(dev_handle);
 			return (rc);
 		}
 	}
@@ -893,7 +862,7 @@ int main(int argc, char *argv[])
 	if (rc != 0) {
 		DBG_ERROR(("ujfs_get_dev_size: FAILED rc = %lld\n", rc))
 		    message_user(MSG_OSO_FORMAT_FAILED, NULL, 0, OSO_MSG);
-		close(dev_handle);
+		fclose(dev_handle);
 		return (rc);
 	}
 
@@ -919,7 +888,7 @@ int main(int argc, char *argv[])
 			message_user(MSG_JFS_PART_SMALL, msg_parms, 1, JFS_MSG);
 		}
 		rc = EINVAL;
-		close(dev_handle);
+		fclose(dev_handle);
 		return (rc);
 	}
 
@@ -932,13 +901,13 @@ int main(int argc, char *argv[])
 		if (requested_blocks > number_of_blocks) {
 			printf("Requested blocks exceed number of blocks on device: %lld.\n",
 			       number_of_blocks);
-			close(dev_handle);
+			fclose(dev_handle);
 			return EINVAL;
 		} else if (requested_blocks < (MINJFS / aggr_block_size)) {
 			strcpy(msgstr, MINJFSTEXT);
 			msg_parms[0] = msgstr;
 			message_user(MSG_JFS_PART_SMALL, msg_parms, 1, JFS_MSG);
-			close(dev_handle);
+			fclose(dev_handle);
 			return EINVAL;
 		}
 		number_of_blocks = requested_blocks;
@@ -962,7 +931,7 @@ int main(int argc, char *argv[])
 			c = getchar();
 
 			if (c == 'n' || c == 'N') {
-				close(dev_handle);
+				fclose(dev_handle);
 				return 0;
 			} else if (c == EOF)
 				abort();
@@ -977,14 +946,15 @@ int main(int argc, char *argv[])
 	 * and we will need a default method of finding and creating the log.
 	 */
 	if (logdev[0] != '\0') {
-		int fd;
+		FILE *fp;
 
+format_journal:
 		/* A log device was specified on the command line.  Call 
 		   * jfs_logform() to initialize the log */
-		fd = open(logdev, LogOpenMode, 0);
-		if (fd < 0) {
+		fp = fopen_excl(logdev, "r+");
+		if (fp == NULL) {
 			message_user(MSG_OSO_FORMAT_FAILED, NULL, 0, OSO_MSG);
-			close(dev_handle);
+			fclose(dev_handle);
 			return -1;
 		}
 		/* 
@@ -993,7 +963,7 @@ int main(int argc, char *argv[])
 		 */
 		if (ext_journal_opt == use_existing_journal) {
 			struct logsuper logsup;
-			rc = ujfs_get_logsuper(fd, &logsup);
+			rc = ujfs_get_logsuper(fp, &logsup);
 			if (!rc) {
 				/* see if superblock is JFS log superblock */
 				rc = ujfs_validate_logsuper(&logsup);
@@ -1024,22 +994,22 @@ int main(int argc, char *argv[])
 			    && volume_label) {
 				label_ptr = volume_label;
 			}
-			rc = jfs_logform(fd, aggr_block_size,
+			rc = jfs_logform(fp, aggr_block_size,
 					 log2shift(aggr_block_size),
 					 type_jfs | type_commit, 0, 0, log_uuid,
 					 label_ptr);
 		}
-		close(fd);
+		fclose(fp);
 		if (rc != 0) {
 			message_user(MSG_OSO_FORMAT_FAILED, NULL, 0, OSO_MSG);
 			DBG_ERROR(("Internal error: Format failed rc=%x\n", rc))
-			    close(dev_handle);
+			    fclose(dev_handle);
 			return (rc);
 		} else if (ext_journal_opt == create_journal_only) {
 			printf
 			    ("\nJFS external journal created SUCCESSFULLY on %s.\n",
 			     logdev);
-			close(dev_handle);
+			fclose(dev_handle);
 			return (rc);
 		}
 	} else {
@@ -1069,7 +1039,7 @@ int main(int argc, char *argv[])
 			rc = ENOSPC;
 			message_user(MSG_OSO_FORMAT_FAILED, NULL, 0, OSO_MSG);
 			DBG_ERROR(("Internal error: Format failed rc=%x\n", rc))
-			    close(dev_handle);
+			    fclose(dev_handle);
 			return (rc);
 		}
 
@@ -1082,7 +1052,7 @@ int main(int argc, char *argv[])
 		if (rc != 0) {
 			message_user(MSG_OSO_FORMAT_FAILED, NULL, 0, OSO_MSG);
 			DBG_ERROR(("Internal error: Format failed rc=%x\n", rc))
-			    close(dev_handle);
+			    fclose(dev_handle);
 			return (rc);
 		}
 	}
@@ -1095,7 +1065,7 @@ int main(int argc, char *argv[])
 			      type_jfs | type_commit, logdev, logloc, logsize,
 			      verify_blocks, log_uuid);
 	ujfs_flush_dev(dev_handle);
-	close(dev_handle);
+	fclose(dev_handle);
 	/* Format Complete message */
 	if (rc == 0) {
 		message_user(MSG_OSO_FORMAT_COMPLETE, NULL, 0, OSO_MSG);
