@@ -86,7 +86,7 @@ void alter()
 		fputs("alter: malloc failure!\n", stderr);
 		return;
 	}
-	if (ujfs_rw_diskblocks(fd, address, length, buffer, GET)) {
+	if (ujfs_rw_diskblocks(fp, address, length, buffer, GET)) {
 		fputs("alter: failed reading disk data!\n", stderr);
 		free(buffer);
 		return;
@@ -121,7 +121,7 @@ void alter()
 
 		buffer[offset++] = byte;
 	}
-	if (ujfs_rw_diskblocks(fd, address, length, buffer, PUT))
+	if (ujfs_rw_diskblocks(fp, address, length, buffer, PUT))
 		fputs("alter: failed writing disk data!\n", stderr);
 
 	free(buffer);
