@@ -89,7 +89,7 @@ void dmap()
 
 	/* Read overall control page for the map */
 
-	if (ujfs_rwdaddr(fd, &cntl_addr, &bmap_inode, (int64_t) 0, GET, bsize) ||
+	if (ujfs_rwdaddr(fp, &cntl_addr, &bmap_inode, (int64_t) 0, GET, bsize) ||
 	    xRead(cntl_addr, sizeof (struct dbmap), (char *) &cntl_page)) {
 		fputs("dmap: Error reading aggregate dmap control page\n", stderr);
 		return;
@@ -298,7 +298,7 @@ int display_cpage(struct dinode * bmap_inode, int64_t * lblock)
 
 	type = decode_pagenum(*lblock, &l1, &l0, &dmap);
 
-	if (ujfs_rwdaddr(fd, &address, bmap_inode, (*lblock) << dmap_l2bpp,
+	if (ujfs_rwdaddr(fp, &address, bmap_inode, (*lblock) << dmap_l2bpp,
 			 GET, bsize) || xRead(address, sizeof (struct dmapctl), (char *) &ctl_page)) {
 		fputs("display_cpage: Error reading control page!\n", stderr);
 		return DMAP_EXIT;
@@ -492,7 +492,7 @@ int display_leaf(struct dinode * bmap_inode, int64_t * lblock)
 
 	decode_pagenum(*lblock, &l1, &l0, &dmap);
 
-	if (ujfs_rwdaddr(fd, &address, bmap_inode, (*lblock) << dmap_l2bpp,
+	if (ujfs_rwdaddr(fp, &address, bmap_inode, (*lblock) << dmap_l2bpp,
 			 GET, bsize) || xRead(address, sizeof (struct dmap), (char *) &d_map)) {
 		fputs("display_leaf: Error reading dmap page!\n", stderr);
 		return DMAP_EXIT;
