@@ -34,14 +34,14 @@ int xRead(int64_t address, unsigned count, char *buffer)
 	length = (offset + count + bsize - 1) & ~(bsize - 1);
 
 	if ((offset == 0) & (length == count))
-		return ujfs_rw_diskblocks(fd, address, count, buffer, GET);
+		return ujfs_rw_diskblocks(fp, address, count, buffer, GET);
 
 	block_address = address - offset;
 	block_buffer = (char *) malloc(length);
 	if (block_buffer == 0)
 		return 1;
 
-	if (ujfs_rw_diskblocks(fd, block_address, length, block_buffer, GET)) {
+	if (ujfs_rw_diskblocks(fp, block_address, length, block_buffer, GET)) {
 		free(block_buffer);
 		return 1;
 	}
@@ -61,19 +61,19 @@ int xWrite(int64_t address, unsigned count, char *buffer)
 	length = (offset + count + bsize - 1) & ~(bsize - 1);
 
 	if ((offset == 0) & (length == count))
-		return ujfs_rw_diskblocks(fd, address, count, buffer, PUT);
+		return ujfs_rw_diskblocks(fp, address, count, buffer, PUT);
 
 	block_address = address - offset;
 	block_buffer = (char *) malloc(length);
 	if (block_buffer == 0)
 		return 1;
 
-	if (ujfs_rw_diskblocks(fd, block_address, length, block_buffer, GET)) {
+	if (ujfs_rw_diskblocks(fp, block_address, length, block_buffer, GET)) {
 		free(block_buffer);
 		return 1;
 	}
 	memcpy(block_buffer + offset, buffer, count);
-	if (ujfs_rw_diskblocks(fd, block_address, length, block_buffer, PUT)) {
+	if (ujfs_rw_diskblocks(fp, block_address, length, block_buffer, PUT)) {
 		free(block_buffer);
 		return 1;
 	}
