@@ -47,13 +47,13 @@ void superblock()
 		return;
 	}
 
-	if (ujfs_get_superblk(fd, &super, is_primary)) {
+	if (ujfs_get_superblk(fp, &super, is_primary)) {
 		fputs("superblock: error returned from ujfs_get_superblk\n\n", stderr);
 		return;
 	}
 
 	if (display_super(&super) == XPEEK_CHANGED)
-		if (ujfs_put_superblk(fd, &super, (short) is_primary))
+		if (ujfs_put_superblk(fp, &super, (short) is_primary))
 			fputs("superblock: error returned from ujfs_put_superblk\n\n", stderr);
 	return;
 }
