@@ -40,7 +40,7 @@ unsigned type_jfs;
 
 /* Global Data */
 int bsize;			/* aggregate block size         */
-int fd;				/* Used by libfs routines       */
+FILE *fp;				/* Used by libfs routines       */
 short l2bsize;			/* log2 of aggregate block size */
 int64_t AIT_2nd_offset;		/* Used by find_iag routines    */
 int64_t fsckwsp_offset;		/* Used by fsckcbbl routines    */
@@ -74,16 +74,16 @@ int main(int argc, char **argv)
 	device = argv[1];
 
 	/* Open device */
-	fd = open(device, O_RDWR, 0);
-	if (fd < 0) {
+	fp = fopen(device, "r+");
+	if (fp == NULL) {
 		fprintf(stderr, "Error: Cannot open device %s.\n", device);
 		exit(1);
 	}
 
 	/* Get block size information from the superblock       */
-	if (ujfs_get_superblk(fd, &sb, 1)) {
+	if (ujfs_get_superblk(fp, &sb, 1)) {
 		fputs("jfs_debugfs: error reading primary superblock\n", stderr);
-		if (ujfs_get_superblk(fd, &sb, 0)) {
+		if (ujfs_get_superblk(fp, &sb, 0)) {
 			fputs("jfs_debugfs: error reading secondary superblock\n", stderr);
 			goto errorout;
 		} else
@@ -152,7 +152,7 @@ int main(int argc, char **argv)
 		fflush(stdout);
 	}
       errorout:
-	ujfs_flush_dev(fd);
-	close(fd);
+	ujfs_flush_dev(fp);
+	fclose(fp);
 	return 0;
 }
